<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- List Coordinates Report -->
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="../_Themes/CDOT/theme.css"/>
                <link rel="stylesheet" type="text/css" href="_Themes/CDOT/theme.css"/>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/CDOT/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">List Coordinates Report</title>
            </head>
            <body>
                <xsl:for-each select="InRoads">
                    <center>
                        <!-- Report Title -->
			            <h1>&#xa0;</h1>                        
                        <h2 lang="en">List Coordinates Report</h2>
                        <p lang="en">
                            Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                            Time:&#xa0; <xsl:value-of select="inr:time()"/>
                        </p>
                    </center>
                    <!-- Project Data -->
                    <xsl:for-each select="GeometryProject">
                        <table class="margin" cellpadding="2" width="90%">
                            <tbody>
                                <tr>
                                    <th align="right" lang="en">Project:&#xa0; </th>
                                    <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                </tr>
                                <tr>
                                    <th align="right" lang="en">Description:&#xa0; </th>
                                    <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                </tr>
                                <tr>
                                    <th align="right" lang="en">File Name:&#xa0; </th>
                                    <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                </tr>
                                <tr>
                                    <th align="right" lang="en">Last Revised:&#xa0; </th>
                                    <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                </tr>
                               <!-- <tr>
                                    <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                    <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                    <td align="right" lang="en" style="font-size: 80%">
                                        <strong>Note:&#xa0; </strong>All units in this report are in
                                        <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                        <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                        unless specified otherwise.
                                    </td>
                                </tr> -->
                            </tbody>
                        </table>
                        <hr />
                        <!-- Horizontal Alignment Data -->
                        <xsl:for-each select="HorizontalAlignment">
                            <table cellpadding="4">
                                <tbody>
                                    <tr>
                                        <th align="right" lang="en">Alignment Name:</th>
                                        <td align="left">
                                            <xsl:value-of select="@name"/>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <table class="margin" cellpadding="2" cellspacing="5" width="90%">
                                <thead>
                                    <tr>
                                        <th class="underline" lang="en">POINT<br />NAME</th>
                                       <!-- <th class="underline" lang="en">Type</th> -->
                                        <th class="underline" lang="en">NORTH (ft)</th>
                                        <th class="underline" lang="en">EAST (ft)</th>
                                        <th class="underline" lang="en">ELEV (ft)</th>
                                        <!--<th class="underline" lang="en">Style</th> -->
										 <th class="underline" lang="en">DESCRIPTION</th>
										 <th class="underline" lang="en">EXTENDED<br />DESCRIPTION</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="HorizontalElements">
                                        <xsl:apply-templates/>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </xsl:for-each>
                        <!-- Cogo Point Data -->
                        <xsl:for-each select="CogoPoints">
                            <table cellpadding="4">
                                <tbody>
                                    <tr>
                                        <th align="left" lang="en">Cogo Points</th>
                                    </tr>
                                </tbody>
                            </table>
                            <table class="margin" cellpadding="2" cellspacing="5" width="90%"> 
                                <thead>
                                    <tr>
                                        <th class="underline" lang="en">POINT<br />NAME</th>
                                       <!-- <th class="underline" lang="en">Type</th> -->
                                        <th class="underline" lang="en">NORTH (ft)</th>
                                        <th class="underline" lang="en">EAST (ft)</th>
                                        <th class="underline" lang="en">ELEV (ft)</th>
                                       <!-- <th class="underline" lang="en">Style</th> -->
									   <th class="underline" lang="en">DESCRIPTION</th>
									   <th class="underline" lang="en">EXTENDED<br />DESCRIPTION</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="GeometryPoint">
                                        <tr>
                                            <td align="center"><xsl:value-of select="@name"/></td>
                                           <!-- <td align="center"><xsl:value-of select="@type"/></td> -->
                                            <td align="right"><xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/></td>
                                            <td align="right"><xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/></td>
                                            <td align="right"><xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/></td>
                                           <!-- <td align="center"><xsl:value-of select="@style"/></td> -->
										   <td align="center"><xsl:value-of select="@description"/></td>
										   <td align="center"><xsl:value-of select="@extendedDescription"/></td>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>
    <!-- Element Point Data -->
    <xsl:template match="Start | PI | Center | End[@type='POE']">
        <tr>
            <td align="center"><xsl:value-of select="@name"/></td>
           <!-- <td align="center"><xsl:value-of select="@type"/></td> -->
            <td align="right"><xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/></td>
            <td align="right"><xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/></td>
            <td align="right"><xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/></td>
           <!-- <td align="center"><xsl:value-of select="@style"/></td> -->
        </tr>
    </xsl:template>
</xsl:stylesheet>
