<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Superelevation Station Report -->
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cross Slope Optimization Station Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cross Slope Optimization Station Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="RoadwayDesignProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Corridor:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@corridorName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@designFileName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
		                           <xsl:for-each select="CrossSlopeOptimizationExistingInput">
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%"><strong>Existing Ground Data:&#xa0; </strong></th>
                                                <td align="left" lang="en" style="font-size: 80%">Type: <xsl:value-of select="@type"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                                <td align="left" lang="en" style="font-size: 80%">Pivot: <xsl:value-of select="@pivot"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                                <td align="left" lang="en" style="font-size: 80%">Superelevated: <xsl:value-of select="@superelevated"/></td>
                                            </tr>
                                        </xsl:for-each>
		                           <xsl:for-each select="CrossSlopeOptimizationDesignInput">
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%"><strong>Design Data:&#xa0; </strong></th>
                                                <td align="left" lang="en" style="font-size: 80%">Type: <xsl:value-of select="@type"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                                 <td align="left" lang="en" style="font-size: 80%">
                                                     <xsl:if test="@type = 'Control Line'">Control Line: <xsl:value-of select="@controlLine"/></xsl:if>
                                                     <xsl:if test="@type = 'Constant'">Design Cross Slope: <xsl:value-of select="inr:gradeFormat(number(@fixedValue), $xslGradeFormat, $xslGradePrecision)"/></xsl:if>
                                                 </td>
                                            </tr>
                                        </xsl:for-each>
		                           <xsl:for-each select="CrossSlopeOptimizationParameters">
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%"><strong>Optimization Parameters:&#xa0; </strong></th>
                                                <td align="left" lang="en" style="font-size: 80%">Tolerance Type: <xsl:value-of select="@toleranceType"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                                 <td align="left" lang="en" style="font-size: 80%">
                                                     <xsl:if test="@toleranceType = 'Slope'">Slope Tolerance: <xsl:value-of select="inr:gradeFormat(number(@toleranceValue), $xslGradeFormat, $xslGradePrecision)"/></xsl:if>
                                                     <xsl:if test="@toleranceType = 'Elevation'">Elevation Tolerance: <xsl:value-of select="inr:elevationFormat(number(@toleranceValue), $xslElevationPrecision)"/></xsl:if>
							  </td>
						    </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Cross Slope Optimization Station Data -->
                                <table class="margin" cellpadding="1" cellspacing="1" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Station</th>
                                            <th align="right" lang="en">Existing<br/>
													 Slope/Elevation</th>
                                            <th align="right" lang="en">Design<br/>
                                              							 Slope/Elevation</th>
                                            <th align="right" lang="en">Difference<br/>
                                                                                       Slope/Elevation</th>
                                            <th align="right" lang="en">Corrected<br/>
												       Slope/Elevation</th>
                                            <th align="right" lang="en">Delta G</th>
                                        </tr>
                                        <xsl:for-each select="CrossSlopeOptimizationStations">
                                            <xsl:for-each select="CrossSlopeOptimizationStation">
                                                <tr>
                                                    <th align="right" valign="top">
                                                        <xsl:value-of select="inr:stationFormat(number(@externalStation), $xslStationFormat, $xslStationPrecision, string(@externalStationName))"/>
                                                    </th>
                                                    <th align="right">
                                                        <xsl:value-of select="inr:gradeFormat(number(@existingGroundSlope), $xslGradeFormat, $xslGradePrecision)"/><br/>
                                                        <xsl:value-of select="inr:elevationFormat(number(@existingGroundElevationDelta), $xslElevationPrecision)"/>
                                                    </th>
                                                    <th align="right">
                                                        <xsl:value-of select="inr:gradeFormat(number(@designSlope), $xslGradeFormat, $xslGradePrecision)"/><br/>
                                                        <xsl:value-of select="inr:elevationFormat(number(@designElevationDelta), $xslElevationPrecision)"/>
                                                    </th>
                                                    <th align="right">
                                                        <xsl:value-of select="inr:gradeFormat(number(@slopeDifference), $xslGradeFormat, $xslGradePrecision)"/><br/>
                                                        <xsl:value-of select="inr:elevationFormat(number(@elevationDifference), $xslElevationPrecision)"/>
                                                    </th>
                                                    <th align="right">
                                                        <xsl:value-of select="inr:gradeFormat(number(@correctedSlope), $xslGradeFormat, $xslGradePrecision)"/><br/>
                                                        <xsl:value-of select="inr:elevationFormat(number(@correctedElevationDelta), $xslElevationPrecision)"/>
                                                    </th>
                                                    <th align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@deltaG), $xslGradeFormat, $xslElevationPrecision)"/>
                                                    </th>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross slope optimization results by selecting the Calculate Results button
                from the <em>Modeler &gt; Roadway Designer &gt; Overlay Tools 
                &gt; Cross Slope Optimization</em> command.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
