<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- GDOT Minimum Longitudinal Slope ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:text>==================================================================&#xd;</xsl:text>
                    <xsl:text> GDOT formatted file for reporting profile stations where the&#xd;</xsl:text>
                    <xsl:text> longitudinal grade &lt; 1.0% and the road cross slope &lt; 0.5%&#xd;</xsl:text>
                    <xsl:text>==================================================================&#xd;</xsl:text>
                    <xsl:for-each select="CrossSectionSet">
                        <xsl:text> Cross Section Set Name:  </xsl:text>
                        <xsl:value-of select="@setName"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>         Alignment Name:  </xsl:text>
                        <xsl:value-of select="@alignmentName"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>         Report Created:  </xsl:text>
                        <xsl:value-of select="inr:date()"/><xsl:text>&#xa0;</xsl:text>
                        <xsl:value-of select="inr:time()"/><xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="CrossSectionStations">
                            <xsl:text>==================================================================&#xd;</xsl:text>
                            <xsl:text>     Station     Center     Longitudinal  Left      Right&#xd;</xsl:text>
                            <xsl:text>                Elevation      Grade      Slope     Slope&#xd;</xsl:text>
                            <xsl:text>------------------------------------------------------------------&#xd;</xsl:text>
                            <xsl:for-each select="CrossSectionStation[CrossSectionSurfaces]">
                                <xsl:for-each select="CrossSectionSurfaces/CrossSectionSurface[@type = '1']/CrossSectionPoints[CrossSectionPoint/CrossSectionFeatures]">
                                    <xsl:variable name="leftCrossSlope" select="number(-1 * ((CrossSectionPoint[CrossSectionFeatures][2]/@elevation - CrossSectionPoint[CrossSectionFeatures][1]/@elevation) div (CrossSectionPoint[CrossSectionFeatures][2]/@offset - CrossSectionPoint[CrossSectionFeatures][1]/@offset)))"/>
                                    <xsl:variable name="rightCrossSlope" select="number((CrossSectionPoint[CrossSectionFeatures][3]/@elevation - CrossSectionPoint[CrossSectionFeatures][2]/@elevation) div (CrossSectionPoint[CrossSectionFeatures][3]/@offset - CrossSectionPoint[CrossSectionFeatures][2]/@offset))"/>
                                    <!--xsl:text>&#xd;left cross slope =</xsl:text><xsl:value-of select="$leftCrossSlope"/>
                                    <xsl:text>    right cross slope =</xsl:text><xsl:value-of select="$rightCrossSlope"/><xsl:text>&#xd;</xsl:text-->
                                    <xsl:choose>
                                        <xsl:when test="$leftCrossSlope &gt; -0.005 and $leftCrossSlope &lt; 0.005">
                                            <xsl:choose>
                                                <xsl:when test="CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &gt; -0.01 and CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &lt; 0.01 and $rightCrossSlope &gt; -0.005 and $rightCrossSlope &lt; 0.005">
                                                    <xsl:variable name="testLeft" select="inr:testLeft(number(1))"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))), 12)"/>
                                                    <xsl:value-of select="inr:columnDoubleFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/@elevation), $xslElevationPrecision, 13)"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope), 2, $xslGradePrecision)), 11)"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number($leftCrossSlope), 2, $xslGradePrecision)), 11)"/>
                                                    <xsl:if test="CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &gt; -0.01 and CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &lt; 0.01">
                                                        <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number($rightCrossSlope), 2, $xslGradePrecision)), 11)"/>
                                                        <xsl:text>&#xd;</xsl:text>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:when test="CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &gt; -0.01 and CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &lt; 0.01">
                                                    <xsl:variable name="testLeft" select="inr:testLeft(number(1))"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))), 12)"/>
                                                    <xsl:value-of select="inr:columnDoubleFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/@elevation), $xslElevationPrecision, 13)"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope), 2, $xslGradePrecision)), 11)"/>
                                                    <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number($leftCrossSlope), 2, $xslGradePrecision)), 11)"/>
                                                    <xsl:text>&#xd;</xsl:text>
                                                </xsl:when>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:when test="$rightCrossSlope &gt; -0.005 and $rightCrossSlope &lt; 0.005">
                                            <xsl:if test="CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &gt; -0.01 and CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope &lt; 0.01">
                                                <xsl:variable name="testRight" select="inr:testRight(number(1))"/>
                                                <xsl:value-of select="inr:columnFormat(string(inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))), 12)"/>
                                                <xsl:value-of select="inr:columnDoubleFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/@elevation), $xslElevationPrecision, 13)"/>
                                                <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number(CrossSectionPoint[CrossSectionFeatures][2]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope), 2, $xslGradePrecision)), 11)"/>
                                                <xsl:value-of select="inr:columnFormat(string(inr:gradeFormat(number($rightCrossSlope), 2, $xslGradePrecision)), 22)"/>
                                                <xsl:text>&#xd;</xsl:text>
                                            </xsl:if>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:variable name="notMet" select="inr:criteriaMet(number(1))"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                    <xsl:variable name="comply" select="inr:finalCheck(1)"/>
                    <xsl:if test="$comply = 2">
                        <xsl:text>&#xd;Surface </xsl:text>
                        <xsl:value-of select="CrossSectionSet/CrossSectionStations/CrossSectionStation/CrossSectionSurfaces/CrossSectionSurface/@name"/>
                        <xsl:text> complies with Design Criteria</xsl:text>
                    </xsl:if>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have created cross sections along your&#xd;</xsl:text>
        <xsl:text>    alignment and the cross section set must have the&#xd;</xsl:text>
        <xsl:text>    design surface and features upon which you wish to&#xd;</xsl:text>
        <xsl:text>    report displayed.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Selected Features Only&#xd;</xsl:text>
        <xsl:text>    option on the Evaluation &gt; Cross Section &gt; Cross&#xd;</xsl:text>
        <xsl:text>    Section Report command and you must select only three&#xd;</xsl:text>
        <xsl:text>    features, typically those representing the left and&#xd;</xsl:text>
        <xsl:text>    right edges of pavement and the centerline, to get&#xd;</xsl:text>
        <xsl:text>    valid results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            var leftArray = new Array(100);
            var rightArray = new Array(100);
            met = 0;
            leftArray[0] = 0;
            rightArray[0] = 0;
            function testLeft(input)
            {
                leftArray[0] = 1;
                return 1;
            }
            function testRight(input)
            {
                rightArray[0] = 1;
                return 1;
            }
            function criteriaMet(input)
            {
                met = input;
                return 1;
            }	
            function finalCheck(y)
            {
                if ((leftArray[0] == 1) && (rightArray[0] == 1))
                    return 1;
                if ((leftArray[0] == 1) && (rightArray[0] == 0))
                    return 1;
                if ((leftArray[0] == 0) && (rightArray[1] == 1))
                    return 1;
                if ((leftArray[0] == 1) && (rightArray[0] == 0))
                    return 1;
                else;
                    return 2;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
