<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Alignment to AGTEK Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>UNITS=</xsl:text>
                    <xsl:choose>
                        <xsl:when test="//@linearUnits = 'Imperial'">FEET&#xd;&#xd;</xsl:when>
                        <xsl:otherwise>METRIC&#xd;&#xd;</xsl:otherwise>
                    </xsl:choose>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>NEW STATION </xsl:text>
                        <xsl:value-of select="inr:distanceFormat(number(HorizontalElements/*[1]/Start/station/@internalStation), 6)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>OLD STATION </xsl:text>
                        <xsl:value-of select="inr:distanceFormat(number(HorizontalElements/*[1]/Start/station/@internalStation), 6)"/>
                        <xsl:text>&#xd;&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                        <xsl:for-each select="VerticalAlignment/VerticalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="HorizontalLine">
        <xsl:text>STATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LENGTH </xsl:text><xsl:value-of select="inr:distanceFormat(number(@length), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>NORTH </xsl:text><xsl:value-of select="inr:northingFormat(number(Start/@northing), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>EAST  </xsl:text><xsl:value-of select="inr:eastingFormat(number(Start/@easting), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LATITUDE </xsl:text><xsl:value-of select="inr:directionFormatAGTEK(number(@direction), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalCircle">
        <xsl:text>STATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LENGTH </xsl:text><xsl:value-of select="inr:distanceFormat(number(@length), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>NORTH </xsl:text><xsl:value-of select="inr:northingFormat(number(Start/@northing), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>EAST  </xsl:text><xsl:value-of select="inr:eastingFormat(number(Start/@easting), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LATITUDE ARC&#xd;</xsl:text>
        <xsl:text>ANGLE </xsl:text><xsl:value-of select="inr:angularFormatAGTEK(number(@delta), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>ARC-DIRECTION </xsl:text>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'cw'">RIGHT&#xd;</xsl:when>
            <xsl:otherwise>LEFT&#xd;</xsl:otherwise>
        </xsl:choose>
        <xsl:text>RADIUS </xsl:text><xsl:value-of select="inr:distanceFormat(number(@radius), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>TANGENT </xsl:text><xsl:value-of select="inr:distanceFormat(number(@tangentLength), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="HorizontalSpiral">
        <xsl:text>STATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(Start/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LENGTH </xsl:text><xsl:value-of select="inr:distanceFormat(number(@length), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>NORTH </xsl:text><xsl:value-of select="inr:northingFormat(number(Start/@northing), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>EAST  </xsl:text><xsl:value-of select="inr:eastingFormat(number(Start/@easting), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>LATITUDE SPIRAL&#xd;</xsl:text>
        <xsl:text>INCREASING </xsl:text>
        <xsl:choose>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalLine'] and following-sibling::*[1][name() = 'HorizontalCircle']">
                <xsl:text>TRUE&#xd;</xsl:text>
                <xsl:text>ARC-ANGLE </xsl:text>
                <xsl:value-of select="inr:angularFormatAGTEK(number(following-sibling::*[1]/@delta), 6)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text>ARC-DIRECTION </xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'cw'">RIGHT&#xd;</xsl:when>
                    <xsl:otherwise>LEFT&#xd;</xsl:otherwise>
                </xsl:choose>
                <xsl:text>RADIUS </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), 6)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalCircle'] and following-sibling::*[1][name() = 'HorizontalLine']">
                <xsl:text>FALSE&#xd;</xsl:text>
                <xsl:text>ARC-ANGLE </xsl:text>
                <xsl:value-of select="inr:angularFormatAGTEK(number(preceding-sibling::*[1]/@delta), 6)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text>ARC-DIRECTION </xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'cw'">RIGHT&#xd;</xsl:when>
                    <xsl:otherwise>LEFT&#xd;</xsl:otherwise>
                </xsl:choose>
                <xsl:text>RADIUS </xsl:text>
                <xsl:value-of select="inr:distanceFormat(number(preceding-sibling::*[1]/@radius), 6)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="@endRadius &gt; @startRadius">
                        <xsl:text>TRUE&#xd;</xsl:text>
                        <xsl:text>ARC-ANGLE </xsl:text>
                        <xsl:value-of select="inr:angularFormatAGTEK(number(preceding-sibling::*[1]/@delta), 6)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>ARC-DIRECTION </xsl:text>
                        <xsl:choose>
                            <xsl:when test="@rotationDirection = 'cw'">RIGHT&#xd;</xsl:when>
                            <xsl:otherwise>LEFT&#xd;</xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>RADIUS </xsl:text>
                        <xsl:value-of select="preceding-sibling::*[1]/@radius"/>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>FALSE&#xd;</xsl:text>
                        <xsl:text>ARC-ANGLE </xsl:text>
                        <xsl:value-of select="inr:angularFormatAGTEK(number(following-sibling::*[1]/@delta), 6)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>ARC-DIRECTION </xsl:text>
                        <xsl:choose>
                            <xsl:when test="@rotationDirection = 'cw'">RIGHT&#xd;</xsl:when>
                            <xsl:otherwise>LEFT&#xd;</xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>RADIUS </xsl:text>
                        <xsl:value-of select="following-sibling::*[1]/@radius"/>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template match="VerticalLine">
        <xsl:text>VSTATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VTYPE SLOPE&#xd;</xsl:text>
        <xsl:text>VLENGTH </xsl:text><xsl:value-of select="inr:distanceFormat(number(@length), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VSLOPE </xsl:text><xsl:value-of select="inr:gradeFormat(number(@grade * 100), 1, 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VELEVATION </xsl:text><xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>VSTATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>VSLOPE </xsl:text><xsl:value-of select="inr:gradeFormat(number(@grade * 100), 1, 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>VELEVATION </xsl:text><xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:text>VSTATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VTYPE CURVE&#xd;</xsl:text>
        <xsl:text>VLENGTH </xsl:text><xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VSLOPE </xsl:text><xsl:value-of select="inr:gradeFormat(number(@startGrade * 100), 1, 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>VELEVATION </xsl:text><xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), 6)"/><xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>VSTATION </xsl:text><xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>VSLOPE </xsl:text><xsl:value-of select="inr:gradeFormat(number(@startGrade * 100), 1, 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>VELEVATION </xsl:text><xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), 6)"/><xsl:text>&#xd;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report is not suitable for unsymmetric parabolas&#xd;</xsl:text>
        <xsl:text>    or vertical circles.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets directional information to AGTEK format.
            // n - value from XML
            // precision - the number of digits after the decimal point
            function directionFormatAGTEK(n, precision)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater
                    // than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    var decdeg = (n * 180) / Math.PI;
                    //identifies 1st quadrant
                    if (decdeg <= 90)
                    {
                        var strAngle = angularFormatAGTEK(n, precision);
                        return "NORTH \n" + "BEARING " + strAngle + "\nDEPARTURE EAST";
                    }
                    //identifies 2nd quadrant
                    if (90 < decdeg && decdeg <= 180)
                    {
                        n = Math.PI - n;
                        var strAngle = angularFormatAGTEK(n, precision);
                        return "SOUTH \n" + "BEARING " + strAngle + "\nDEPARTURE EAST";
                    }
                    //identifies 3rd quadrant 
                    if (180 < decdeg && decdeg < 270)
                    {
                        n -= Math.PI;
                        var strAngle = angularFormatAGTEK(n, precision);
                        return "SOUTH \n" + "BEARING " + strAngle + "\nDEPARTURE WEST";
                    }
                    //identifies 4th quadrant
                    if (270 <= decdeg && decdeg < 360)
                    {
                        n = (2.0 * Math.PI) - n;
                        var strAngle = angularFormatAGTEK(n, precision);
                        return "NORTH \n" + "BEARING " + strAngle + "\nDEPARTURE WEST";
                    }
                }
                return "";
             }
            // This function sets the angular information to AGTEK format.
            // n - value from xml
            // precision - the number of digits after the decimal point
            function angularFormatAGTEK(n, precision)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    var decdeg = (n * 180) / Math.PI;
                    // takes only the whole number (ddd)
                    deg = Math.floor(Math.abs(decdeg));
                    // multiplies the decimal portion time 60 to get the minutes.
                    var decmin = (Math.abs(decdeg) - deg) * 60;
                    // takes only the whole part of that number (mm')
                    var min = Math.floor(decmin);
                    // multiplies the decimal portion time 60 to get the seconds.
                    var decsec = (decmin - min) * 60;
                    // this calls the function that gives the number the correct precision
                    var str = formatNumber(decsec, precision);
                    if (  str.substring(0,2) == "60" )
                    {
                        decsec = 0;
                        str = formatNumber(decsec, precision);
                        min = min+1;
                        if ( min == 60 )
                        {
                            min = 0;
                            deg = deg + 1;
                        }
                    }
                    var sec = str;
                    var msg;
                    if( decdeg >= 0 || decdeg <= -1 )
                    {
                        if( decdeg < 0 )
                            msg =  "-" + deg + " " + min + " " + sec + " ";
                        else
                            msg =  deg + " " + min + " " + sec + " ";
                    }
                    else
                        msg =  "-0" + " " + min + " " + sec + " ";
                }
                return msg;
             }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
