<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="pi" select="inr:setPI()"/>
    <!-- Variables to hold unit strings -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> FEET</xsl:when>
            <xsl:otherwise> METERS</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="unitSingular">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> FOOT</xsl:when>
            <xsl:otherwise> METER</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Variable to hold tangency tolerance -->
    <xsl:variable name="tangentTol" select="number(0.1 div 3600)"/>
    <!-- Tucson Legal Description Format -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <!--link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/-->
                <style type="text/css">body{font-family:Tahoma;}</style>
                <!-- Title displayed in browser Title Bar -->
                <title>Tucson Legal Description Format</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/GeometryProject">
                            <p lang="en">
                                <img src="{$xslRootDirectory}/Images/RickLogoLg.png" alt="Rick Engineering" height="66" width="148"/>
                                <br/>
                            </p>
                            <center><h3 lang="en">TUCSON LEGAL DESCRIPTION</h3></center>
                            <xsl:for-each select="HorizontalAlignment">
                                THAT PORTION OF __________ SURVEYED BY __________<br/><br/>
                                <strong>COMMENCING</strong> AT THE _____ CORNER;<br/>
                                &#xa0; &#xa0; &#xa0; &#xa0; THENCE __________ TO THE <strong>POINT OF BEGINNING;</strong><br/>
                                <xsl:apply-templates/>
                                <xsl:choose>
                                    <xsl:when test="@area &gt; 0">
                                        TO THE <strong>POINT OF BEGINNING.</strong><br/><br/>
                                        CONTAINING
                                        <xsl:choose>
                                            <xsl:when test="//@linearUnits = 'Metric'">
                                                <xsl:value-of select="format-number(number(inr:areaFormat(number(@area), $xslAreaPrecision)), '#,###.##')"/>
                                                SQUARE METERS OR
                                                <xsl:value-of select="inr:acreFormat(number(@area) div 10000, $xslAcrePrecision)"/>
                                                HECTARES,
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="format-number(number(inr:areaFormat(number(@area), $xslAreaPrecision)), '#,###.##')"/>
                                                SQUARE FEET OR
                                                <xsl:value-of select="inr:acreFormat(number(@area) div 43560, $xslAcrePrecision)"/>
                                                ACRES,
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        MORE OR LESS.
                                    </xsl:when>
                                    <xsl:otherwise>
                                        TO THE <strong>POINT OF TERMINATION.</strong>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each>
                            <center>
                                <p lang="en">
                                    <span style="font-size:xx-small;font-family:'Times New Roman';">
                                        1745 East River Road &#xb7; Suite 101 &#xb7; Tucson &#xb7; Arizona 
                                        &#xb7; 85718 &#xb7; (520) 795-1000 &#xb7; Fax: (520) 322-6956 &#xb7; 
                                        www.rickengineering.com
                                    </span>
                                </p>
                            </center>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line -->
    <xsl:template match="HorizontalLine">
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @direction"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="position() = 1">
                &#xa0; &#xa0; &#xa0; &#xa0; THENCE CONTINUE
            </xsl:when>
            <xsl:otherwise>
                &#xa0; &#xa0; &#xa0; &#xa0; THENCE
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:tucDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:choose>
            <xsl:when test="position() = last()">
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <!-- Find the direction perpendicular to the chord direction -->
                        <xsl:variable name="concaveDirection">
                            <xsl:choose>
                                <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (1.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (1.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (1.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (0.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (0.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (0.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:value-of select="$unit"/>
                        <xsl:choose>
                            <!-- Direction of current line is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                <xsl:choose>
                                    <!-- Current line is radial to following curve -->
                                    <xsl:when test="(@direction - following-sibling::*[1]/@radialDirectionStart &gt; -$tangentTol and @direction - following-sibling::*[1]/@radialDirectionStart &lt; $tangentTol) or (@direction - following-sibling::*[1]/@radialDirectionStart &gt; $pi - $tangentTol and @direction - following-sibling::*[1]/@radialDirectionStart &lt; $pi + $tangentTol)">
                                        RADIAL TO THE NEXT DESCRIBED CURVE CONCAVE
                                        <xsl:call-template name="directionAdverbComma">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        TO A POINT ON THE ARC OF SAID CURVE;<br/>
                                    </xsl:when>
                                    <!-- Current line is not radial to following curve -->
                                    <xsl:otherwise>
                                        <xsl:choose>
                                            <!-- Angle difference between current line and following curve is tangent or nearly tangent, but goes back on itself -->
                                            <xsl:when test="$angDiffAhead &gt; $pi - $tangentTol and $angDiffAhead &lt; $pi + $tangentTol">
                                                TO A POINT OF CUSP OF A TANGENT CURVE CONCAVE
                                                <xsl:call-template name="directionAdverbSemiColon">
                                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                                </xsl:call-template>
                                            </xsl:when>
                                            <!-- Angle difference between current line and following curve is less than 45 degrees -->
                                            <xsl:when test="$angDiffAhead &gt; 0.75 * $pi">
                                                TO A POINT OF CUSP OF A NON-TANGENT CURVE CONCAVE
                                                <xsl:call-template name="directionAdverbComma">
                                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                                </xsl:call-template>
                                                THE RADIUS POINT OF SAID CURVE BEARS
                                                <xsl:choose>
                                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                        <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:when>
                                            <!-- Simple non-tangent following curve -->
                                            <xsl:otherwise>
                                                TO A NON-TANGENT CURVE CONCAVE
                                                <xsl:call-template name="directionAdverbComma">
                                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                                </xsl:call-template>
                                                THE RADIUS POINT OF SAID CURVE BEARS
                                                <xsl:choose>
                                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                        <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Otherwise, the following curve is tangent -->
                            <xsl:otherwise>
                                TO A TANGENT CURVE CONCAVE
                                <xsl:call-template name="directionAdverbSemiColon">
                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                </xsl:call-template>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        &#xa0; &#xa0; &#xa0; &#xa0; SPIRALS NOT SUPPORTED;<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$unit"/>;<br/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Circle -->
    <xsl:template match="HorizontalCircle">
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="angDiffAheadLin">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd&gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@direction - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="position() = 1">
                &#xa0; &#xa0; &#xa0; &#xa0; THENCE CONTINUE
            </xsl:when>
            <xsl:otherwise>
                &#xa0; &#xa0; &#xa0; &#xa0; THENCE
            </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="directionAdverb">
            <xsl:with-param name="inputDir" select="@chordDirection"/>
        </xsl:call-template>
        UPON THE ARC OF SAID CURVE TO THE
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'"> LEFT,</xsl:when>
            <xsl:otherwise> RIGHT,</xsl:otherwise>
        </xsl:choose>
        HAVING A RADIUS OF
        <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
        <xsl:value-of select="$unit"/>
        AND A CENTRAL ANGLE OF
        <xsl:value-of select="inr:tucAngularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>,
        FOR AN ARC DISTANCE OF
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:choose>
            <xsl:when test="position() = last()">
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <!-- Find the direction perpendicular to the chord direction -->
                        <xsl:variable name="concaveDirection">
                            <xsl:choose>
                                <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (1.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (1.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (1.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (0.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (0.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (0.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:choose>
                            <!-- End direction of current curve is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                <xsl:value-of select="$unit"/>
                                <xsl:choose>
                                    <!-- Angle difference between current curve and following curve is tangent or nearly tangent, but goes back on itself -->
                                    <xsl:when test="($angDiffAhead &gt; $pi - $tangentTol) and ($angDiffAhead &lt; $pi + $tangentTol)">
                                        TO A POINT OF CUSP OF A TANGENT CURVE CONCAVE
                                        <xsl:call-template name="directionAdverbSemiColon">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <!-- Angle difference between current curve and following curve is less than 45 degrees -->
                                    <xsl:when test="$angDiffAhead &gt; 0.75 * $pi">
                                        TO A POINT OF CUSP OF A NON-TANGENT CURVE CONCAVE
                                        <xsl:call-template name="directionAdverbComma">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        THE RADIUS POINT OF SAID CURVE BEARS
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <!-- Simple non-tangent following curve -->
                                    <xsl:otherwise>
                                        <xsl:choose>
                                            <!-- If directions are not equal, it is a reverse curve -->
                                            <xsl:when test="@rotationDirection != following-sibling::*[1]/@rotationDirection">
                                                TO A POINT OF REVERSE CURVATURE
                                            </xsl:when>
                                            <!-- Otherwise, it is a compound -->
                                            <xsl:otherwise>
                                                TO A POINT OF COMPOUND CURVATURE
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        OF A NON-TANGENT CURVE CONCAVE
                                        <xsl:call-template name="directionAdverbComma">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        THE RADIUS POINT OF SAID CURVE BEARS
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:tucDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Otherwise, following curve is tangent -->
                            <xsl:otherwise>
                                <xsl:choose>
                                    <!-- If directions are not equal, it is a reverse curve -->
                                    <xsl:when test="@rotationDirection != following-sibling::*[1]/@rotationDirection">
                                        <xsl:value-of select="$unit"/>
                                        TO A POINT OF REVERSE CURVATURE
                                    </xsl:when>
                                    <!-- Otherwise, it is a compound -->
                                    <xsl:otherwise>
                                        <xsl:value-of select="$unit"/>
                                        TO A POINT OF COMPOUND CURVATURE
                                    </xsl:otherwise>
                                </xsl:choose>
                                OF A TANGENT CURVE CONCAVE
                                <xsl:call-template name="directionAdverbSemiColon">
                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                </xsl:call-template>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        &#xa0; &#xa0; &#xa0; &#xa0; SPIRALS NOT SUPPORTED;<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:choose>
                            <!-- End direction of current curve is not equal to direction of following line -->
                            <xsl:when test="$angDiffAheadLin &gt; $tangentTol">
                                <xsl:value-of select="$unit"/>
                                <xsl:choose>
                                    <!-- Angle difference between current curve and following line is tangent or nearly tangent, but goes back on itself -->
                                    <xsl:when test="$angDiffAheadLin &gt; $pi - $tangentTol and $angDiffAheadLin &lt; $pi + $tangentTol">
                                        TO A POINT OF CUSP WITH A TANGENT LINE;<br/>
                                    </xsl:when>
                                    <!-- Angle difference between current curve and following curve is less than 45 degrees -->
                                    <xsl:when test="$angDiffAheadLin &gt; 0.75 * $pi">
                                        TO A POINT OF CUSP WITH A NON-TANGENT LINE;<br/>
                                    </xsl:when>
                                    <!-- Simple non-tangent following line -->
                                    <xsl:otherwise>
                                        TO A NON-TANGENT LINE;<br/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Otherwise, following line is tangent -->
                            <xsl:otherwise>
                                <xsl:value-of select="$unit"/>
                                TO A TANGENT LINE;<br/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverb">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.125 * $pi and $inputDir &lt; 0.375 * $pi">
                NORTHEASTERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.375 * $pi and $inputDir &lt; 0.625 * $pi">
                EASTERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.525 * $pi and $inputDir &lt; 0.875 * $pi">
                SOUTHEASTERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.875 * $pi and $inputDir &lt; 1.125 * $pi">
                SOUTHERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.125 * $pi and $inputDir &lt; 1.375 * $pi">
                SOUTHWESTERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.375 * $pi and $inputDir &lt; 1.625 * $pi">
                WESTERLY
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.625 * $pi and $inputDir &lt; 1.875 * $pi">
                NORTHWESTERLY
            </xsl:when>
            <xsl:otherwise>
                NORTHERLY
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverbComma">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.125 * $pi and $inputDir &lt; 0.375 * $pi">
                NORTHEASTERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.375 * $pi and $inputDir &lt; 0.625 * $pi">
                EASTERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.625 * $pi and $inputDir &lt; 0.875 * $pi">
                SOUTHEASTERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.875 * $pi and $inputDir &lt; 1.125 * $pi">
                SOUTHERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.125 * $pi and $inputDir &lt; 1.375 * $pi">
                SOUTHWESTERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.375 * $pi and $inputDir &lt; 1.625 * $pi">
                WESTERLY,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.625 * $pi and $inputDir &lt; 1.875 * $pi">
                NORTHWESTERLY,
            </xsl:when>
            <xsl:otherwise>
                NORTHERLY,
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverbSemiColon">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.125 * $pi and $inputDir &lt; 0.375 * $pi">
                NORTHEASTERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.375 * $pi and $inputDir &lt; 0.625 * $pi">
                EASTERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.625 * $pi and $inputDir &lt; 0.875 * $pi">
                SOUTHEASTERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.875 * $pi and $inputDir &lt; 1.125 * $pi">
                SOUTHERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.125 * $pi and $inputDir &lt; 1.375 * $pi">
                SOUTHWESTERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.375 * $pi and $inputDir &lt; 1.625 * $pi">
                WESTERLY;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.625 * $pi and $inputDir &lt; 1.875 * $pi">
                NORTHWESTERLY;<br/>
            </xsl:when>
            <xsl:otherwise>
                NORTHERLY;<br/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Legal Description</em> or the <em>Tools &gt; XML Reports 
                &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for a reference alignment or for alignments containing spirals.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of directional information with North, East, South and West
            // spelled out fully.
            // n - value from XML
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // precision - the number of digits after the decimal point
            // mode - (1 - Bearing, 2 - Bearings from North Only, 3 - North Azimuth, 4 - South Azimuth)
            function tucDirectionFormat(n, format, precision, mode, method)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    // mode 1 - Bearing, mode 2 - North Bearing
                    if (mode == 1 || mode == 2)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // identifies the quadrant
                        if (decdeg <= 90)
                        {
                            var strAngle = tucAngularFormat(n, format, precision, method);
                            return "NORTH " + strAngle + " EAST";
                        }
                        // identifies the quadrant
                        if (90 < decdeg && decdeg <= 180)
                        {
                            n = Math.PI - n;
                            var strAngle = tucAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "SOUTH " + strAngle + " EAST";
                            }
                            else
                            {
                                return "NORTH " + strAngle + " WEST";
                            }
                        }
                        // identifies the quadrant 
                        if (180 < decdeg && decdeg < 270)
                        {
                            n -= Math.PI;
                            var strAngle = tucAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "SOUTH " + strAngle + " WEST";
                            }
                            else
                            {
                                return "NORTH " + strAngle + " EAST";
                            }
                        }
                        // identifies the quadrant
                        if (270 <= decdeg && decdeg < 360)
                        {
                            n = (2.0 * Math.PI) - n;
                            var strAngle = tucAngularFormat(n, format, precision, method);
                            return "NORTH " + strAngle + " WEST";
                        }
                    }
                    // mode 3 - North Azimuth
                    if (mode == 3)
                    {
                        var strAngle = tucAngularFormat(n, format, precision, method);
                        return strAngle;
                    }
                    // mode 4 - South Azimuth
                    if (mode == 4)
                    {
                        n = n + Math.PI;
                        if (n >= (2.0 * Math.PI))
                        {
                            n = n - (2.0 * Math.PI);
                        }
                        var strAngle = tucAngularFormat(n, format, precision, method);
                        return strAngle;
                     }
                }
                return "NaN";
             }
            // This function sets the format of angular information.
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function tucAngularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if (formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to "ddd^mm'ss.s"
                        if (format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            if (deg < 10)
                            {
                                deg = "0" + deg;
                            }
                            // multiplies the decimal portion by 60 to get the minutes
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            // takes only the whole part of that number (mm')
                            var min = Math.floor(decmin);
                            // multiplies the decimal portion by 60 to get the seconds
                            var decsec = (decmin - min) * 60;
                            // calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            if (str.substring(0,2) == "60")
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min + 1;
                                if (min == 60)
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                            if (min < 10)
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if (sec < 10)
                            {
                                sec = "0" + sec;
                            }
                            var msg;
                            if (decdeg >= 0 || decdeg <= -1)
                            {
                                if (decdeg < 0)
                                {
                                    msg =  "-" + deg + unescape("%b0") + min + "'" + sec + '"';
                                }
                                else
                                {
                                    msg =  deg + unescape("%b0") + min + "'" + sec + '"';
                                }
                            }
                            else
                            {
                                msg =  "-0" + unescape("%b0") + min + "'" + sec + '"';
                            }
                            return msg;
                        }
                        // format 2 - "ddd.ddd"
                        if (format == 2)
                        {
                            // calls the function that gives the number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + unescape("%b0");
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if (formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (useAngSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if (formatMethod == 3)
                    {
                        // calls the function that gives the number the correct precision
                        var radian = formatNumber(n, precision);
                        if (useAngSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if (formatMethod == 4)
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber(radtomils, precision);
                         return mils;
                    }
                }
                return "NaN";
            }
            function setPI()
            {
                var strPI = Math.PI;
                return strPI;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
