<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Alignment to TIW Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY HORIZONTAL ALIGNMENT TO TIW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:text>*</xsl:text>
                        <xsl:value-of select="inr:columnFormat('X Coord', 13)"/>
                        <xsl:value-of select="inr:columnFormat('Y Coord', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Radius', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Leading Spiral', 18)"/>
                        <xsl:value-of select="inr:columnFormat('Trailing Spiral', 16)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalCurveSets">
                            <xsl:apply-templates/>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Curveset Point Data -->
    <xsl:template match="CurvesetPoint">
        <xsl:choose>
            <!-- First Point -->
            <xsl:when test="@pointType = 'POB'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- No Circle -->
            <xsl:when test="@pointType = 'PI'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Simple Circle -->
            <xsl:when test="@pointType = 'CIRCLE'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:choose>
                    <xsl:when test="../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * ../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Leading Spiral Circle -->
            <xsl:when test="@pointType = 'SPIRAL CIRCLE'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:choose>
                    <xsl:when test="../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * ../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStartElement]/@length), $xslDistancePrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Circle Trailing Spiral -->
            <xsl:when test="@pointType = 'CIRCLE SPIRAL'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:choose>
                    <xsl:when test="../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * ../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStopElement]/@length), $xslDistancePrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Spiral Circle Spiral -->
            <xsl:when test="@pointType = 'SPIRAL CIRCLE SPIRAL'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:choose>
                    <xsl:when test="../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * ../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalCircle[@elementNumber = current()/@curveSetStartElement + 1]/@radius), $xslDistancePrecision, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStartElement]/@length), $xslDistancePrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(../../HorizontalElements/HorizontalSpiral[@elementNumber = current()/@curveSetStopElement]/@length), $xslDistancePrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Last Point -->
            <xsl:when test="@pointType = 'POE'">
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@easting), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(GeometryPoint/@northing), $xslNorthingPrecision, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <!-- Compound curve -->
            <xsl:otherwise>
                <xsl:text>*** Unsupported element ***&#xd;</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
