<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">11</xsl:when>
            <xsl:otherwise>10</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Horizontal Elements - Leica GSI8 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="is0-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="//HorizontalAlignment">
                    <xsl:text/>
                    <xsl:text>41....+</xsl:text>
                    <xsl:choose>
                        <xsl:when test="string-length(@name) &gt; 8">
                            <xsl:value-of select="substring(@name, 1, 8)"/>
                        </xsl:when>
                        <xsl:when test="string-length(@name) &lt; 8">
                            <xsl:value-of select="substring('00000000', 1, 8 - string-length(@name))"/>
                            <xsl:value-of select="@name"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="@name"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:text> 42....+HZALIGNM 43....+STACOORD&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalElements">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="HorizontalLine">
        <!-- Find absolute value -->
        <xsl:variable name="absStartEasting">
            <xsl:choose>
                <xsl:when test="Start/@easting &lt; 0"><xsl:value-of select="number(-1 * Start/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartNorthing">
            <xsl:choose>
                <xsl:when test="Start/@northing&lt; 0"><xsl:value-of select="number(-1 * Start/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="Start/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * Start/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndEasting">
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0"><xsl:value-of select="number(-1 * End/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndNorthing">
            <xsl:choose>
                <xsl:when test="End/@northing&lt; 0"><xsl:value-of select="number(-1 * End/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * End/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartEasting" select="inr:zeroDoubleFormat(number($absStartEasting), 3, 8)"/>
        <xsl:variable name="fmtStartNorthing" select="inr:zeroDoubleFormat(number($absStartNorthing), 3, 8)"/>
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 3, 8)"/>
        <xsl:variable name="fmtEndEasting" select="inr:zeroDoubleFormat(number($absEndEasting), 3, 8)"/>
        <xsl:variable name="fmtEndNorthing" select="inr:zeroDoubleFormat(number($absEndNorthing), 3, 8)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 3, 8)"/>
        <xsl:text>11....</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/station/@internalStation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 8)"/>
        <xsl:text> 71....+STRAIGHT 72....+00000NON 73....+00000000 81..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="Start/@easting &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartEasting"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 82..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="Start/@northing &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartNorthing"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>11....</xsl:text>
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 8)"/>
            <xsl:text> 71....+00000EOP 72....+00000NON 73....+00000000 81..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndEasting) &gt; 8">
                    <xsl:value-of select="substring($fmtEndEasting, (string-length($fmtEndEasting) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndEasting"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text> 82..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@northing &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndNorthing) &gt; 8">
                    <xsl:value-of select="substring($fmtEndNorthing, (string-length($fmtEndNorthing) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndNorthing"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circlular Data -->
    <xsl:template match="HorizontalCircle">
        <!-- Find absolute value -->
        <xsl:variable name="absStartEasting">
            <xsl:choose>
                <xsl:when test="Start/@easting &lt; 0"><xsl:value-of select="number(-1 * Start/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartNorthing">
            <xsl:choose>
                <xsl:when test="Start/@northing&lt; 0"><xsl:value-of select="number(-1 * Start/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="Start/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * Start/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndEasting">
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0"><xsl:value-of select="number(-1 * End/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndNorthing">
            <xsl:choose>
                <xsl:when test="End/@northing&lt; 0"><xsl:value-of select="number(-1 * End/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * End/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartEasting" select="inr:zeroDoubleFormat(number($absStartEasting), 3, 8)"/>
        <xsl:variable name="fmtStartNorthing" select="inr:zeroDoubleFormat(number($absStartNorthing), 3, 8)"/>
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 3, 8)"/>
        <xsl:variable name="fmtEndEasting" select="inr:zeroDoubleFormat(number($absEndEasting), 3, 8)"/>
        <xsl:variable name="fmtEndNorthing" select="inr:zeroDoubleFormat(number($absEndNorthing), 3, 8)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 3, 8)"/>
        <xsl:text>11....</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/station/@internalStation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 8)"/>
        <xsl:text> 71....+000CURVE 72....</xsl:text>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:zeroDoubleFormat(number(@radius), 3, 8)"/>
        <xsl:text> 73....+00000000 81..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="Start/@easting &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartEasting"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 82..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="Start/@northing &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtStartNorthing"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>11....</xsl:text>
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 8)"/>
            <xsl:text> 71....+00000EOP 72....+00000NON 73....+00000000 81..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndEasting) &gt; 8">
                    <xsl:value-of select="substring($fmtEndEasting, (string-length($fmtEndEasting) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndEasting"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text> 82..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@northing &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndNorthing) &gt; 8">
                    <xsl:value-of select="substring($fmtEndNorthing, (string-length($fmtEndNorthing) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndNorthing"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <!-- Find absolute value -->
        <xsl:variable name="absStartEasting">
            <xsl:choose>
                <xsl:when test="Start/@easting &lt; 0"><xsl:value-of select="number(-1 * Start/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartNorthing">
            <xsl:choose>
                <xsl:when test="Start/@northing&lt; 0"><xsl:value-of select="number(-1 * Start/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absStartStation">
            <xsl:choose>
                <xsl:when test="Start/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * Start/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(Start/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndEasting">
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0"><xsl:value-of select="number(-1 * End/@easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndNorthing">
            <xsl:choose>
                <xsl:when test="End/@northing&lt; 0"><xsl:value-of select="number(-1 * End/@northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEndStation">
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:value-of select="number(-1 * End/station/@internalStation)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="number(End/station/@internalStation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtStartEasting" select="inr:zeroDoubleFormat(number($absStartEasting), 3, 8)"/>
        <xsl:variable name="fmtStartNorthing" select="inr:zeroDoubleFormat(number($absStartNorthing), 3, 8)"/>
        <xsl:variable name="fmtStartStation" select="inr:zeroDoubleFormat(number($absStartStation), 3, 8)"/>
        <xsl:variable name="fmtEndEasting" select="inr:zeroDoubleFormat(number($absEndEasting), 3, 8)"/>
        <xsl:variable name="fmtEndNorthing" select="inr:zeroDoubleFormat(number($absEndNorthing), 3, 8)"/>
        <xsl:variable name="fmtEndStation" select="inr:zeroDoubleFormat(number($absEndStation), 3, 8)"/>
        <xsl:text>11....</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/station/@internalStation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="substring($fmtStartStation, 1, 8)"/>
        <xsl:choose>
            <xsl:when test="@startRadius = 0">
                <xsl:text> 71....+00SPIRIN 72....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@aConstant), 3, 8)"/>
                <xsl:text> 73....+00000000 81..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@easting &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                        <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartEasting"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text> 82..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@northing &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                        <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartNorthing"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="@endRadius = 0">
                <xsl:text> 71....+0SPIROUT 72....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@aConstant), 3, 8)"/>
                <xsl:text> 73....+00000000 81..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@easting &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                        <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartEasting"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text> 82..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@northing &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                        <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartNorthing"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="@startRadius &gt; @endRadius">
                <xsl:text> 71....+0CURVEIN 72....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@startRadius), 3, 8)"/>
                <xsl:text> 73....+00000000 74....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@endRadius), 3, 8)"/>
                <xsl:text> 81..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@easting &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                        <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartEasting"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text> 82..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@northing &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                        <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartNorthing"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="@startRadius &lt; @endRadius">
                <xsl:text> 71....+CURVEOUT 72....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@startRadius), 3, 8)"/>
                <xsl:text> 73....+00000000 74....</xsl:text>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:value-of select="inr:zeroDoubleFormat(number(@endRadius), 3, 8)"/>
                <xsl:text> 81..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@easting &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartEasting) &gt; 8">
                        <xsl:value-of select="substring($fmtStartEasting, (string-length($fmtStartEasting) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartEasting"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text> 82..</xsl:text>
                <xsl:value-of select="$unit"/>
                <xsl:choose>
                    <xsl:when test="Start/@northing &lt; 0">
                        <xsl:text>-</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>+</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:choose>
                    <xsl:when test="string-length($fmtStartNorthing) &gt; 8">
                        <xsl:value-of select="substring($fmtStartNorthing, (string-length($fmtStartNorthing) - 7), 8)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$fmtStartNorthing"/>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
        </xsl:choose>
        <xsl:if test="position() = last()">
            <xsl:text>11....</xsl:text>
            <xsl:choose>
                <xsl:when test="End/station/@internalStation &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="substring($fmtEndStation, 1, 8)"/>
            <xsl:text> 71....+00000EOP 72....+00000NON 73....+00000000 81..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@easting &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndEasting) &gt; 8">
                    <xsl:value-of select="substring($fmtEndEasting, (string-length($fmtEndEasting) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndEasting"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text> 82..</xsl:text>
            <xsl:value-of select="$unit"/>
            <xsl:choose>
                <xsl:when test="End/@northing &lt; 0">
                    <xsl:text>-</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>+</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <xsl:when test="string-length($fmtEndNorthing) &gt; 8">
                    <xsl:value-of select="substring($fmtEndNorthing, (string-length($fmtEndNorthing) - 7), 8)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$fmtEndNorthing"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet reports coordinates and distances to&#xd;</xsl:text>
        <xsl:text>    the nearest 1/1000th foot or the nearest 1/1000th&#xd;</xsl:text>
        <xsl:text>    meter, depending on the units stored in the XML data&#xd;</xsl:text>
        <xsl:text>    file.  If the resulting coordinate is too long to fit&#xd;</xsl:text>
        <xsl:text>    in the field, only the last 8 digits (including the&#xd;</xsl:text>
        <xsl:text>    decimal portion) will be retained.  However, stations,&#xd;</xsl:text>
        <xsl:text>    distances, radii, etc will retain the first 8 digits&#xd;</xsl:text>
        <xsl:text>    (truncating the decimal portion.)&#xd;&#xd;</xsl:text>
        <xsl:text>    If you wish to use a different precision, you must&#xd;</xsl:text>
        <xsl:text>    change the "unit" variable near the top of the style&#xd;</xsl:text>
        <xsl:text>    sheet as well as the precision value wherever the&#xd;</xsl:text>
        <xsl:text>    "zeroDoubleFormat" function is called.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function formats a string with a length, padding with leading zeros
            // strString - String to get formated
            // nLength - Length of returned string
            function zeroFormat( strString, nLength )
            {
                var nBlanks = nLength - strString.length;
                for( var i = 0; i < nBlanks; i++ )
                    strString = "0" + strString;
                return strString;
            }
            // This function converts a double to string and sets precision and length, padding with leading zeros
            // dNum - Double to be converted to String
            // nPrecision - the number of digits after the decimal point
            // nLength - Length of returned string
            function zeroDoubleFormat( dNum, nPrecision, nLength )
            {
                var nRoundTo = Math.pow( 10, nPrecision );
                var strResult = ( Math.round( nRoundTo * dNum ) ).toString();
                var nCount = strResult.length - strResult.indexOf( "." ) - 1;
                for( var j = 0; j < (nPrecision - nCount); j++ )
                    strResult += "0";
                var nBlanks = nLength - strResult.length;
                for( var i = 0; i < nBlanks; i++ )
                    strResult = "0" + strResult;
                return strResult;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
