<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- TDS ForeSight DXM LandXML to TDS RW5 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="LandXML">
                    <xsl:for-each select="Project">
                        <xsl:text/>
                        <xsl:text>JB,NMM-</xsl:text>
                        <xsl:value-of select="@name"/>
                        <xsl:text>,DT</xsl:text>
                        <xsl:value-of select="inr:tdsDate()"/>
                        <xsl:text>,TM</xsl:text>
                        <xsl:value-of select="inr:tdsTime()"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="//CgPoint">
                            <xsl:text>SP,PN</xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:call-template name="outputCoords">
                                <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                            </xsl:call-template>
                            <xsl:text>,--</xsl:text>
                            <xsl:value-of select="@code"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="../Feature/*/TdsFeaProperty">
                                <xsl:text>--.</xsl:text><xsl:value-of select="@label"/>
                                <xsl:text> </xsl:text><xsl:value-of select="@value"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="outputCoords">
        <xsl:param name="list"/>
        <xsl:variable name="NCoord" select="substring-before($list, ' ')"/>
        <xsl:variable name="restAfterN" select="substring-after($list, ' ')"/>
        <xsl:variable name="ECoord" select="substring-before($restAfterN, ' ')"/>
        <xsl:variable name="restAfterE" select="substring-after($restAfterN, ' ')"/>
        <xsl:variable name="ElCoord" select="substring-before($restAfterE, ' ')"/>
        <xsl:variable name="restAfterEl" select="substring-after($restAfterE, ' ')"/>
        <xsl:text>,N </xsl:text>
        <xsl:value-of select="$NCoord"/>
        <xsl:text>,E </xsl:text>
        <xsl:value-of select="$ECoord"/>
        <xsl:text>,EL</xsl:text>
        <xsl:value-of select="$ElCoord"/>
        <xsl:if test="$restAfterEl">
            <xsl:call-template name="outputCoords">
                <xsl:with-param name="list" select="$restAfterEl"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must comment out or delete the schema information&#xd;</xsl:text>
        <xsl:text>    in the LandXML file produced by TDS ForeSight DXM(tm)&#xd;</xsl:text>
        <xsl:text>    to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet reports CgPoint data only.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript"><![CDATA[
            // This function gets the current time.
            function tdsTime()
            {
                var today = new Date();
                var hours = today.getHours();
                var setting = "";
                var minutes = today.getMinutes();
                var seconds = today.getSeconds();
                if (minutes < 10)
                {
                    minutes = "0" + minutes;
                }
                if (seconds < 10)
                {
                    seconds = "0" + seconds;
                }
                return hours + ":" + minutes + ":" + seconds;
            }
            // This function gets the current date.
            function tdsDate()
            {
                var today = new Date();
                var month = today.getMonth() + 1;
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                return month + "-" + dayOfMonth + "-" + year;
            }
        ]]></msxsl:script>
</xsl:stylesheet>
