<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- Cross Section All Features Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cross Section All Features Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cross Section All Features Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Set Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Cross Section Point Data -->
                                <table class="margin" width="75%">
                                    <xsl:for-each select="$uniqueSurfaceName[../CrossSectionFeatures]">
                                        <thead style="display-group:header">
                                            <tr>
                                                <th align="left" lang="en">Surface:&#xa0; </th>
                                                <td align="left" colspan="3"><xsl:value-of select="."/></td>
                                            </tr>
                                            <tr>
                                                <th class="underline" rowspan="2" valign="bottom">Station</th>
                                                <th colspan="3">- - - - - - - Feature - - - - - - -</th>
                                            </tr>
                                            <tr>
                                                <th class="underline">Name</th>
                                                <th class="underline">Elevation</th>
                                                <th class="underline">Offset</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="//CrossSectionSurface[@name = current()][CrossSectionFeatures]">
                                                <tr>
                                                    <th class="sidepad" align="right" nowrap="nowrap">
                                                        <br/><xsl:value-of select="inr:stationFormat(number(../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../Station/@externalStationName))"/>
                                                    </th>
                                                </tr>
                                                <xsl:for-each select="CrossSectionFeatures/CrossSectionFeature/CrossSectionFeaturePoints">
                                                    <xsl:sort select="CrossSectionFeaturePoint/@offset" data-type="number"/>
                                                    <xsl:call-template name="showFeaturePointData">
                                                        <xsl:with-param name="list" select="CrossSectionFeaturePoint[../../@name]"/>
                                                    </xsl:call-template>
                                                </xsl:for-each>
                                            </xsl:for-each>
                                            <tr><td colspan="4">&#xa0;</td></tr>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="showFeaturePointData">
        <xsl:param name="list"/>
        <xsl:param name="rest" select="$list[position() &gt; 1]"/>
        <tr>
            <td>&#xa0;</td>
            <td valign="bottom"><xsl:value-of select="$list[1]/../../@name"/></td>
            <td class="sidepad" align="right" valign="bottom">
                <xsl:value-of select="inr:elevationFormat(number($list[1]/@elevation), $xslElevationPrecision)"/>
            </td>
            <td class="sidepad" align="right" valign="bottom">
                <xsl:value-of select="inr:distanceFormat(number($list[1]/@offset), $xslDistancePrecision)"/>
            </td>
        </tr>
        <xsl:if test="$rest">
            <tr>
                <td class="sidepad"> &#xa0; </td>
                <xsl:call-template name="showFeaturePointData">
                    <xsl:with-param name="list" select="$rest"/>
                </xsl:call-template>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>Evaluation &gt; Cross Section &gt; Cross 
                Section Report</em> command or from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
