<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="cubicUnitLabel">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">cu ft</xsl:when>
            <xsl:otherwise>cu m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Triangle Volume Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Triangle Volume Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Triangle Volume Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Triangle Volume Sets -->
                            <xsl:for-each select="TriangleVolumeSurfaceSets">
                                <table class="margin" cellpadding="2">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap">Mode:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@method"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%" nowrap="nowrap" valign="top">
                                                Input Grid Factor: &#xa0;
                                            </th>
                                            <td align="left" style="font-size: 80%" valign="top">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Volume Data -->
                                <table class="margin">
                                    <xsl:for-each select="TriangleVolumeSurfaceSet">
                                        <tbody>
                                            <tr>
                                                <th align="right" lang="en">Original Surface:&#xa0; </th>
                                                <th align="left" colspan="2"><xsl:value-of select="@existingSurface"/></th>
                                            </tr>
                                            <xsl:if test="@existingSurfaceDescription">
                                                <tr>
                                                    <td align="right" lang="en">Description:&#xa0; </td>
                                                    <td colspan="2"><xsl:value-of select="@existingSurfaceDescription"/></td>
                                                </tr>
                                            </xsl:if>
                                            <xsl:if test="@existingSurfaceStyle">
                                                <tr>
                                                    <td align="right" lang="en">Preference:&#xa0; </td>
                                                    <td colspan="2"><xsl:value-of select="@existingSurfaceStyle"/></td>
                                                </tr>
                                            </xsl:if>
                                            <xsl:if test="@existingSurfaceType">
                                                <tr>
                                                    <td align="right" lang="en">Type:&#xa0; </td>
                                                    <xsl:choose>
                                                        <xsl:when test="@existingSurfaceType = '0'">
                                                            <td colspan="2">Existing</td>
                                                        </xsl:when>
                                                        <xsl:when test="@existingSurfaceType = '1'">
                                                            <td colspan="2">Design</td>
                                                        </xsl:when>
                                                        <xsl:when test="@existingSurfaceType = '2'">
                                                            <td colspan="2">Substratum</td>
                                                        </xsl:when>
                                                        <xsl:when test="@existingSurfaceType = '3'">
                                                            <td colspan="2">Ignore</td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td colspan="2">&#xa0;</td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </tr>
                                            </xsl:if>
                                            <tr>
                                                <th align="right" lang="en">Design Surface:&#xa0; </th>
                                                <th align="left" colspan="2"><xsl:value-of select="@designSurface"/></th>
                                            </tr>
                                            <xsl:if test="@designSurfaceDescription">
                                                <tr>
                                                    <td align="right" lang="en">Description:&#xa0; </td>
                                                    <td colspan="2"><xsl:value-of select="@designSurfaceDescription"/></td>
                                                </tr>
                                            </xsl:if>
                                            <xsl:if test="@designSurfaceStyle">
                                                <tr>
                                                    <td align="right" lang="en">Preference:&#xa0; </td>
                                                    <td colspan="2"><xsl:value-of select="@designSurfaceStyle"/></td>
                                                </tr>
                                            </xsl:if>
                                            <xsl:if test="@designSurfaceType">
                                                <tr>
                                                    <td align="right" lang="en">Type:&#xa0; </td>
                                                    <xsl:choose>
                                                        <xsl:when test="@designSurfaceType = '0'">
                                                            <td colspan="2">Existing</td>
                                                        </xsl:when>
                                                        <xsl:when test="@designSurfaceType = '1'">
                                                            <td colspan="2">Design</td>
                                                        </xsl:when>
                                                        <xsl:when test="@designSurfaceType = '2'">
                                                            <td colspan="2">Substratum</td>
                                                        </xsl:when>
                                                        <xsl:when test="@designSurfaceType = '3'">
                                                            <td colspan="2">Ignore</td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td colspan="2">&#xa0;</td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </tr>
                                            </xsl:if>
                                            <tr>
                                                <th align="right" lang="en">Cut Factor:&#xa0; </th>
                                                <td align="right">
                                                    <xsl:value-of select="inr:distanceFormat(number(@cutFactor), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en">Fill Factor:&#xa0; </th>
                                                <td align="right">
                                                    <xsl:value-of select="inr:distanceFormat(number(@fillFactor), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr><td colspan="3">&#xa0;</td></tr>
                                            <tr>
                                                <td align="right" lang="en">Cut:&#xa0; </td>
                                                <td align="right">
                                                    <xsl:value-of select="inr:cubicFormat(number(@cut), $xslCubicPrecision)"/>
                                                </td>
                                                <td align="left"><xsl:value-of select="$cubicUnitLabel"/></td>
                                            </tr>
                                            <tr>
                                                <td align="right" lang="en">Fill:&#xa0; </td>
                                                <td align="right">
                                                    <xsl:value-of select="inr:cubicFormat(number(@fill), $xslCubicPrecision)"/>
                                                </td>
                                                <td align="left"><xsl:value-of select="$cubicUnitLabel"/></td>
                                            </tr>
                                            <tr>
                                                <td align="right" lang="en">Net:&#xa0; </td>
                                                <td align="right">
                                                    <xsl:value-of select="inr:cubicFormat(number(@netVolume), $xslCubicPrecision)"/>
                                                </td>
                                                <td align="left"><xsl:value-of select="$cubicUnitLabel"/></td>
                                            </tr>
                                            <xsl:if test="//@linearUnits = 'Imperial'">
                                                <tr><td colspan="3">&#xa0;</td></tr>
                                                <tr>
                                                    <td align="right" lang="en">Cut:&#xa0; </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:cubicFormat(number(@cut div 27), $xslCubicPrecision)"/>
                                                    </td>
                                                    <td align="left">cu yd</td>
                                                </tr>
                                                <tr>
                                                    <td align="right" lang="en">Fill:&#xa0; </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:cubicFormat(number(@fill div 27), $xslCubicPrecision)"/>
                                                    </td>
                                                    <td align="left">cu yd</td>
                                                </tr>
                                                <tr>
                                                    <td align="right" lang="en">Net:&#xa0; </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:cubicFormat(number(@netVolume div 27), $xslCubicPrecision)"/>
                                                    </td>
                                                    <td align="left">cu yd</td>
                                                </tr>
                                            </xsl:if>
                                            <tr><td colspan="3">&#xa0;</td></tr>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have added at least two surfaces to the <em>Evaluation &gt; Volumes &gt; Triangle 
                Volume</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
