<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Volumes to CSV -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/CrossSectionSet">
                    <xsl:text/>
                    <xsl:text>setName,alignmentName&#xd;</xsl:text>
                    <xsl:value-of select="@setName"/><xsl:text>,</xsl:text><xsl:value-of select="@alignmentName"/><xsl:text>&#xd;</xsl:text>
                    <xsl:for-each select="CrossSectionStations/CrossSectionStation">
                        <xsl:text>station&#xd;</xsl:text>
                        <xsl:value-of select="inr:stationFormat(number(Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(Station/@externalStationName))"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="StationVolume">
                            <xsl:text>cutArea,fillArea,cutVolume,fillVolume,netVolume,cutFactor,fillFactor,adjustedCutVolume,</xsl:text>
                            <xsl:text>adjustedFillVolume,netAdjustedVolume,addedCutVolume,addedFillVolume,addCutFactor,</xsl:text>
                            <xsl:text>addedFillFactor,adjustedAddedCutVolume,adjustedAddedFillVolume,massOrdinate&#xd;</xsl:text>
                            <xsl:value-of select="CutMaterial/@area"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="FillMaterial/@area"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="CutMaterial/@volume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="FillMaterial/@volume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="@netVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="CutMaterial/@factor"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="FillMaterial/@factor"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="CutMaterial/@adjustedVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="FillMaterial/@adjustedVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="@netAdjustedVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedCutMaterial/@volume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedFillMaterial/@volume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedCutMaterial/@factor"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedFillMaterial/@factor"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedCutMaterial/@adjustedVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="AddedFillMaterial/@adjustedVolume"/><xsl:text>,</xsl:text>
                            <xsl:value-of select="@massOrdinate"/><xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="Materials">
                                <xsl:text>name,type,area,volume,factor,adjustedVolume,includeInMassOrdinate&#xd;</xsl:text>
                                <xsl:for-each select="*/Material">
                                    <xsl:value-of select="@name"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@type"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@area"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@volume"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@factor"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@adjustedVolume"/><xsl:text>,</xsl:text>
                                    <xsl:value-of select="@includeInMassOrdinate"/><xsl:text>,</xsl:text>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have created cross sections along your&#xd;</xsl:text>
        <xsl:text>    alignment and the cross section set must have the&#xd;</xsl:text>
        <xsl:text>    surfaces and features upon which you wish to report&#xd;</xsl:text>
        <xsl:text>    displayed.&#xd;&#xd;</xsl:text>
        <xsl:text>    You can create the XML data file from the End-Area&#xd;</xsl:text>
        <xsl:text>    Volumes leaf of the Evaluation &gt; Cross Section &gt;&#xd;</xsl:text>
        <xsl:text>    Cross Sections command by toggling on the Create&#xd;</xsl:text>
        <xsl:text>    XML Report option on the General leaf or from the&#xd;</xsl:text>
        <xsl:text>    Evaluation &gt; Cross Section &gt; Cross Section Report&#xd;</xsl:text>
        <xsl:text>    command by toggling on the Include Volumes option on&#xd;</xsl:text>
        <xsl:text>    the Main tab.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report is not suitable for MDC.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
