<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Cogo Points with Extended Description Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cogo Points with Extended Description Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cogo Points with Extended Description Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <!-- Cogo Point Data -->
                                <xsl:for-each select="CogoPoints">
                                    <table class="margin" cellpadding="2" cellspacing="1" width="90%">
                                        <colgroup span="2">
                                            <col width="30%"/>
                                            <col width="70%"/>
                                        </colgroup>
                                        <tbody>
                                            <xsl:for-each select="GeometryPoint[@extendedDescription or @link]">
                                                <tr>
                                                    <th align="right" lang="en">Name:&#xa0; </th>
                                                    <td><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Northing:&#xa0; </th>
                                                    <td><xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Easting:&#xa0; </th>
                                                    <td><xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Elevation:&#xa0; </th>
                                                    <td><xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Style:&#xa0; </th>
                                                    <td><xsl:value-of select="@style"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" lang="en">Description:&#xa0; </th>
                                                    <td><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <xsl:if test="@extendedDescription">
                                                    <tr>
                                                        <th align="right" lang="en" valign="top">Extended Description:&#xa0; </th>
                                                        <td><xsl:value-of select="@extendedDescription"/></td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="@link">
                                                    <tr>
                                                        <th align="right" lang="en" valign="top">Link:&#xa0; </th>
                                                        <td>
                                                            <a>
                                                                <xsl:attribute name="href">
                                                                    <xsl:value-of select="@link"/>
                                                                </xsl:attribute>
                                                                <xsl:value-of select="@link"/>
                                                            </a>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <tr><td colspan="2">&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one Cogo point in the <em>Include </em> fields on the <em>Tools 
                &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1">Better results are obtained if your Cogo points have names.</p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
