<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" version="2.0" xmlns:datetime="http://exslt.org/dates-and-times" exclude-result-prefixes="datetime">
    <!-- precision parameters -->
	<xsl:include href="../formatPDF.xsl"/>
	<xsl:template match="InRoads">
		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="first" page-height="11in" page-width="8.5in">
					<fo:region-body margin-left=".75in" margin-top="1.0in" margin-bottom="1.0in" margin-right=".75in"/>
				</fo:simple-page-master>
				<fo:page-sequence-master master-name="my-sequence">
					<fo:repeatable-page-master-alternatives>
						<fo:conditional-page-master-reference page-position="any" master-reference="first"/>
					</fo:repeatable-page-master-alternatives>
				</fo:page-sequence-master>
			</fo:layout-master-set>
			<fo:page-sequence master-reference="first">
				<fo:flow flow-name="xsl-region-body">
					<fo:block font-size="11pt" font-family="Times">
						<fo:block text-align="center" font-size="18pt" font-weight="bold">
			               	Horizontal Alignment Review
				          </fo:block>
						<fo:block text-align="center">
							<xsl:variable name="dateTime" select="datetime:dateTime()"/>
							Created: <xsl:value-of select="datetime:dateTime()"/>
						</fo:block>
						<fo:block space-before="0.25in" font-size="16pt">
							<xsl:apply-templates select="GeometryProject"/>
						</fo:block>
					</fo:block>
				</fo:flow>
			</fo:page-sequence>
		</fo:root>
	</xsl:template>
	<!-- ====================================== -->
	<!-- Geometry Project data -->
	<!-- ====================================== -->
	<xsl:template match="GeometryProject">
		<fo:table table-layout="fixed" width="100%" font-size="11pt">
			<fo:table-column column-width="2in"/>
			<fo:table-column column-width="4in"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">Project:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							<xsl:value-of select="@name"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">Description:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							<xsl:value-of select="@description"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">File Name:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							<xsl:value-of select="@file"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
				<fo:table-row>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">Last Revised:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							<xsl:value-of select="@lastRevisedBy"/>
							<xsl:text>, </xsl:text>
							<xsl:value-of select="@lastRevisedDate"/>
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<fo:table table-layout="fixed" width="100%" font-size="8pt">
			<fo:table-column column-width="2in"/>
			<fo:table-column column-width="1in"/>
			<fo:table-column column-width="1in"/>
			<fo:table-column column-width="3in"/>
			<fo:table-body>
				<fo:table-row>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">Input Grid Factor:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							<xsl:value-of select="../@inputGridScaleFactor"/>
						</fo:block>
					</fo:table-cell>
					<fo:table-cell text-align="right">
						<fo:block font-weight="bold" text-align="right">Note:  </fo:block>
					</fo:table-cell>
					<fo:table-cell>
						<fo:block text-align="left">
							All units in this report are in 
							 <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
							<xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
							  unless specified otherwise. 
						</fo:block>
					</fo:table-cell>
				</fo:table-row>
			</fo:table-body>
		</fo:table>
		<!-- ====================================== -->
		<!-- Horizontal Alignment data -->
		<!-- ====================================== -->
		<xsl:for-each select="HorizontalAlignment">
			<fo:block space-before="0.25in" space-after=".2in">
				<fo:table table-layout="fixed" width="100%" font-size="11pt" margin-top="0.25in" margin-bottom=".20in">
					<fo:table-column column-width="2.5in"/>
					<fo:table-column column-width="3.5in"/>
					<fo:table-body>
						<fo:table-row>
							<fo:table-cell text-align="right">
								<fo:block font-weight="bold" text-align="right">Alignment name: </fo:block>
							</fo:table-cell>
							<fo:table-cell text-align="left">
								<fo:block>
									<xsl:value-of select="@name"/>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell text-align="right">
								<fo:block font-weight="bold" text-align="right">Alignment Description: </fo:block>
							</fo:table-cell>
							<fo:table-cell text-align="left">
								<fo:block>
									<xsl:value-of select="@description"/>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
						<fo:table-row>
							<fo:table-cell text-align="right">
								<fo:block font-weight="bold" text-align="right">Alignment Style: </fo:block>
							</fo:table-cell>
							<fo:table-cell text-align="left">
								<fo:block>
									<xsl:value-of select="@style"/>
								</fo:block>
							</fo:table-cell>
						</fo:table-row>
					</fo:table-body>
				</fo:table>
			</fo:block>
			<fo:table table-layout="fixed" width="100%" font-size="11pt">
				<fo:table-column column-width="20%"/>
				<fo:table-column column-width="15%"/>
				<fo:table-column column-width="15%"/>
				<fo:table-column column-width="15%"/>
				<fo:table-column column-width="15%"/>
				<fo:table-column column-width="15%"/>
				<fo:table-body>
					<fo:table-row>
						<fo:table-cell>
							<fo:block/>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block/>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block/>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-weight="bold">
								<fo:inline text-decoration="underline">
									Station
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-weight="bold">
								<fo:inline text-decoration="underline">
									Northing
								</fo:inline>
							</fo:block>
						</fo:table-cell>
						<fo:table-cell>
							<fo:block font-weight="bold">
								<fo:inline text-decoration="underline">
									Easting
								</fo:inline>
							</fo:block>
						</fo:table-cell>
					</fo:table-row>
					<xsl:for-each select="HorizontalElements">
						<xsl:apply-templates/>
					</xsl:for-each>
				</fo:table-body>
			</fo:table>
		</xsl:for-each>
	</xsl:template>
	<!-- ====================================== -->
	<!-- Horizontal Linear Data -->
	<!-- ====================================== -->
	<xsl:template match="HorizontalLine">
		<fo:table-row>
			<fo:table-cell text-align="right">
				<fo:block>Element: Linear</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="Start/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="Start/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((Start/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(Start/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="Start/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@northing"/>
						<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@easting"/>
						<xsl:with-param name="precision" select="$xslEastingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="End/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="End/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((End/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(End/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="End/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="End/@northing"/>
						<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="End/@easting"/>
						<xsl:with-param name="precision" select="$xslEastingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- ====================================== -->
	<!-- Horizontal Circular Data -->
	<!-- ====================================== -->
	<xsl:template match="HorizontalCircle">
		<fo:table-row>
			<fo:table-cell text-align="right">
				<fo:block>Element: Circular</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="Start/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="Start/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((Start/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(Start/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="Start/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@northing"/>
						<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@easting"/>
						<xsl:with-param name="precision" select="$xslEastingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<xsl:if test="PI">
			<fo:table-row>
				<fo:table-cell>
					<fo:block/>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:value-of select="PI/@type"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:text>(</xsl:text>
						<xsl:value-of select="PI/@name"/>
						<xsl:text>)</xsl:text>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:variable name="val1" select="round((PI/station/@externalStation div 100)-0.5)"/>
						<xsl:variable name="val2" select="round(100*(PI/station/@externalStation - 100*$val1)) div 100"/>
						<xsl:value-of select="PI/station/@externalStationName"/>
						<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
						<xsl:value-of select="$val2"/>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="PI/@northing"/>
							<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
				<fo:table-cell>
					<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="PI/@easting"/>
							<xsl:with-param name="precision" select="$xslEastingPrecision"/>
						</xsl:call-template>
					</fo:block>
				</fo:table-cell>
			</fo:table-row>
		</xsl:if>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="Center/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="Center/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="Center/@northing"/>
							<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="Center/@easting"/>
							<xsl:with-param name="precision" select="$xslEastingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="End/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="End/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((End/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(End/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="End/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="End/@northing"/>
							<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="End/@easting"/>
							<xsl:with-param name="precision" select="$xslEastingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- ====================================== -->
	<!-- Horizontal Spiral Data -->
	<!-- ====================================== -->
	<xsl:template match="HorizontalSpiral">
		<fo:table-row>
			<fo:table-cell text-align="right">
				<fo:block>
					Element:
		                <xsl:choose>
						<xsl:when test="@compound = 'false'">
							<xsl:value-of select="@type"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text> Compound </xsl:text>
							<xsl:value-of select="@type"/>
						</xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="Start/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="Start/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((Start/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(Start/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="Start/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@northing"/>
						<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="Start/@easting"/>
						<xsl:with-param name="precision" select="$xslEastingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="PI/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="PI/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((PI/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(PI/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="PI/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="PI/@northing"/>
						<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:call-template name="Round">
						<xsl:with-param name="num" select="PI/@easting"/>
						<xsl:with-param name="precision" select="$xslEastingPrecision"/>
					</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
		<fo:table-row>
			<fo:table-cell>
				<fo:block/>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:value-of select="End/@type"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="End/@name"/>
					<xsl:text>)</xsl:text>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
					<xsl:variable name="val1" select="round((End/station/@externalStation div 100)-0.5)"/>
					<xsl:variable name="val2" select="round(100*(End/station/@externalStation - 100*$val1)) div 100"/>
					<xsl:value-of select="End/station/@externalStationName"/>
					<xsl:value-of select="$val1"/>+<xsl:if test="$val2 &lt; 10">0</xsl:if>
					<xsl:value-of select="$val2"/>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="End/@northing"/>
							<xsl:with-param name="precision" select="$xslNorthingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
			<fo:table-cell>
				<fo:block>
						<xsl:call-template name="Round">
							<xsl:with-param name="num" select="End/@easting"/>
							<xsl:with-param name="precision" select="$xslEastingPrecision"/>
						</xsl:call-template>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	<!-- ====================================== -->
</xsl:stylesheet>
