<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Intersecting Alignment Stations Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Intersecting Alignment Stations Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Intersecting Alignment Stations Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="HorizontalAlignment">
                                        <tbody>
                                            <tr>
                                                <th align="right" colspan="3"><br/>Alignment Name:&#xa0; </th>
                                                <td align="left" colspan="4" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="3" lang="en">Alignment Description:&#xa0;</th>
                                                <td align="left" colspan="4"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="3" lang="en">Alignment Style:&#xa0;</th>
                                                <td align="left" colspan="4"><xsl:value-of select="@style"/></td>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom"><br/>Point<br/>Type</th>
                                                <th class="underline" valign="bottom">&#xa0;</th>
                                                <th class="underline" lang="en" valign="bottom">Station /<br/>Distance</th>
                                                <th class="underline" valign="bottom">&#xa0;</th>
                                                <th class="underline" lang="en" valign="bottom">Direction</th>
                                                <th class="underline" lang="en" valign="bottom">Northing</th>
                                                <th class="underline" lang="en" valign="bottom">Easting</th>
                                            </tr>
                                            <xsl:apply-templates/>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:variable name="startStation" select="Start/station/@internalStation"/>
        <xsl:variable name="endStation" select="End/station/@internalStation"/>
        <tr>
            <td><xsl:value-of select="Start/@type"/></td>
            <td/>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td colspan="2"/>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td colspan="2"/>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td/>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td colspan="2"/>
        </tr>
        <tr><td colspan="7">&#xa0;</td></tr>
        <xsl:for-each select="../../HorizontalEventPoints">
            <xsl:variable name="list1" select="IntersectingAlignmentPoints/IntersectingAlignmentPoint[primaryAlignmentPoint/station/@internalStation &gt; $startStation]"/>
            <xsl:variable name="list2" select="$list1[primaryAlignmentPoint/station/@internalStation &lt; $endStation]"/>
            <xsl:for-each select="$list2">
                <xsl:sort data-type="number" select="*/station/@internalStation"/>
                <tr>
                    <th align="right" colspan="3">Intersecting Alignment:&#xa0; </th>
                    <td align="left" colspan="4"><xsl:value-of select="@secondaryHorizontalAlignmentName"/></td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">a=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(primaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(primaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="2"/>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(primaryAlignmentPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(primaryAlignmentPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">x=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(secondaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(secondaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="4"/>
                </tr>
                <tr><td colspan="7">&#xa0;</td></tr>
            </xsl:for-each>
        </xsl:for-each>
        <xsl:if test="position() = last()">
            <tr>
                <td><xsl:value-of select="End/@type"/></td>
                <td/>
                <td align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td colspan="2"/>
                <td align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:variable name="startStation" select="Start/station/@internalStation"/>
        <xsl:variable name="endStation" select="End/station/@internalStation"/>
        <tr>
            <td><xsl:value-of select="Start/@type"/></td>
            <td/>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td colspan="2"/>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td/>
            <td align="right" lang="en">LC=</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td align="right" lang="en">CD=</td>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td colspan="2"/>
        </tr>
        <tr>
            <td/>
            <td align="right" lang="en">RC=</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
            <td align="right" lang="en">DC=</td>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td>
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
            <td colspan="2"/>
        </tr>
        <tr>
            <td><xsl:value-of select="PI/@type"/></td>
            <td/>
                <td align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName))"/>
                </td>
            <td colspan="2"/>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PI/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PI/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr><td colspan="7">&#xa0;</td></tr>
        <xsl:for-each select="../../HorizontalEventPoints">
            <xsl:variable name="list1" select="IntersectingAlignmentPoints/IntersectingAlignmentPoint[primaryAlignmentPoint/station/@internalStation &gt; $startStation]"/>
            <xsl:variable name="list2" select="$list1[primaryAlignmentPoint/station/@internalStation &lt; $endStation]"/>
            <xsl:for-each select="$list2">
                <xsl:sort data-type="number" select="*/station/@internalStation"/>
                <tr>
                    <th align="right" colspan="3">Intersecting Alignment:&#xa0; </th>
                    <td align="left" colspan="4"><xsl:value-of select="@secondaryHorizontalAlignmentName"/></td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">a=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(primaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(primaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="2"/>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(primaryAlignmentPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(primaryAlignmentPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">x=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(secondaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(secondaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="4"/>
                </tr>
                <tr><td colspan="7">&#xa0;</td></tr>
            </xsl:for-each>
        </xsl:for-each>
        <xsl:if test="position() = last()">
            <tr>
                <td><xsl:value-of select="End/@type"/></td>
                <td/>
                <td align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td colspan="2"/>
                <td align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:variable name="startStation" select="Start/station/@internalStation"/>
        <xsl:variable name="endStation" select="End/station/@internalStation"/>
        <tr>
            <td><xsl:value-of select="Start/@type"/></td>
            <td/>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td colspan="2"/>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td/>
            <td align="right" lang="en">LS=</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td align="right" lang="en">Theta</td>
            <td align="right" nowrap="nowrap">
                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td>
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
            <td colspan="2"/>
        </tr>
        <tr><td colspan="7">&#xa0;</td></tr>
        <xsl:for-each select="../../HorizontalEventPoints">
            <xsl:variable name="list1" select="IntersectingAlignmentPoints/IntersectingAlignmentPoint[primaryAlignmentPoint/station/@internalStation &gt; $startStation]"/>
            <xsl:variable name="list2" select="$list1[primaryAlignmentPoint/station/@internalStation &lt; $endStation]"/>
            <xsl:for-each select="$list2">
                <xsl:sort data-type="number" select="*/station/@internalStation"/>
                <tr>
                    <th align="right" colspan="3">Intersecting Alignment:&#xa0; </th>
                    <td align="left" colspan="4"><xsl:value-of select="@secondaryHorizontalAlignmentName"/></td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">a=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(primaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(primaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="2"/>
                    <td align="right">
                        <xsl:value-of select="inr:northingFormat(number(primaryAlignmentPoint/@northing), $xslNorthingPrecision)"/>
                    </td>
                    <td align="right">
                        <xsl:value-of select="inr:eastingFormat(number(primaryAlignmentPoint/@easting), $xslEastingPrecision)"/>
                    </td>
                </tr>
                <tr>
                    <td/>
                    <td align="right">x=</td>
                    <td align="right" nowrap="nowrap">
                        <xsl:value-of select="inr:stationFormat(number(secondaryAlignmentPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(secondaryAlignmentPoint/station/@externalStationName))"/>
                    </td>
                    <td colspan="4"/>
                </tr>
                <tr><td colspan="7">&#xa0;</td></tr>
            </xsl:for-each>
        </xsl:for-each>
        <xsl:if test="position() = last()">
            <tr>
                <td><xsl:value-of select="End/@type"/></td>
                <td/>
                <td align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                </td>
                <td colspan="2"/>
                <td align="right">
                    <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one intersecting horizontal alignment in the <em>Include</em> 
                field on the <em>Tools &gt; XML Reports &gt; Intersecting Alignment Stations</em> command 
                to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
