<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- LandXML Vertical Elements Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">LandXML Vertical Elements Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="LandXML">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">LandXML Vertical Elements Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <table class="margin" cellpadding="2" width="90%">
                                <tbody>
                                    <tr>
                                        <th align="right" lang="en">Project:&#xa0; </th>
                                        <td align="left" colspan="2"><xsl:value-of select="Project/@name"/></td>
                                    </tr>
                                    <tr>
                                        <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                        <td align="left" style="font-size: 80%">
                                            <xsl:value-of select="Project/Feature/Property[@label = 'GridScaleFactor']/@value" />
                                        </td>
                                        <td align="right" lang="en" style="font-size: 80%">
                                            <strong>Note:&#xa0; </strong>All units in this report are in
                                            <xsl:if test="Units[Imperial]">feet</xsl:if>
                                            <xsl:if test="Units[Metric]">meters</xsl:if>
                                            unless specified otherwise.
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <hr/>
                            <!-- Horizontal Alignment Data -->
                            <table class="margin" width="75%">
                                <tbody>
                                    <xsl:for-each select="Alignments/Alignment">
                                        <tr>
                                            <th align="right" colspan="2" lang="en"><br/>Alignment Name:&#xa0; </th>
                                            <td align="left" valign="bottom"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" colspan="2" lang="en">Alignment Description:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@desc"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" colspan="2" lang="en">Alignment Style:&#xa0; </th>
                                            <td align="left">
                                                <xsl:value-of select="CoordGeom/*/Feature/Property[@label = 'style']/@value"/>
                                            </td>
                                        </tr>
                                        <xsl:for-each select="Profile/ProfAlign">
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br/>Vertical Alignment Name:&#xa0; </th>
                                                <td align="left" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Vertical Description:&#xa0; </th>
                                                <td align="left"><xsl:value-of select="@desc"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Vertical Style:&#xa0; </th>
                                                <td align="left">
                                                    <xsl:value-of select="Feature/Property[@label = 'style']/@value"/>
                                                </td>
                                            </tr>
                                            <tr><td colspan="3">&#xa0;</td></tr>
                                            <tr>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Elevation</th>
                                                <th class="underline" lang="en">Length</th>
                                                <xsl:choose>
                                                    <xsl:when test="//CircCurve">
                                                        <th class="underline" lang="en">Radius</th>
                                                    </xsl:when>
                                                    <xsl:otherwise/>
                                                </xsl:choose>
                                            </tr>
                                            <xsl:apply-templates/>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="PVI">
        <tr>
            <xsl:call-template name="outputStation">
                <xsl:with-param name="list" select="."/>
            </xsl:call-template>
            <td>&#xa0;</td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="ParaCurve">
        <tr>
            <xsl:call-template name="outputStation">
                <xsl:with-param name="list" select="."/>
            </xsl:call-template>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="UnsymParaCurve">
        <tr>
            <xsl:call-template name="outputStation">
                <xsl:with-param name="list" select="."/>
            </xsl:call-template>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@lengthIn + @lengthOut), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="CircCurve">
        <tr>
            <xsl:call-template name="outputStation">
                <xsl:with-param name="list" select="."/>
            </xsl:call-template>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Coordinates -->
    <xsl:template name="outputStation">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <td align="right">
            <xsl:value-of select="inr:stationFormat(number($first), $xslStationFormat, $xslStationPrecision, '')"/>
        </td>
        <xsl:if test="$rest">
            <xsl:call-template name="outputZCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputZCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:elevationFormat(number($first), $xslElevationPrecision)"/></td>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment with a child vertical alignment in the 
                <em>Include</em> field on the <em>Export Alignment</em> tab of the <em>File &gt; 
                Translators &gt; LandXML Translator</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must also edit the file produced by the <em>LandXML Translator</em> command to remove 
                the following attributes from the LandXML element at the top:
            </p>
            <ul style="list-style-type:none">
                <li>xmlns="http://www.landxml.org/schema/LandXML-1.1"</li>
                <li>xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"</li>
                <li>
                    xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.1 
                    http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd"
                </li>
            </ul>
            <p class="normal1" lang="en">
                The LandXML element should now resemble the following, where the version, date and time are 
                replaced with your actual values:
            </p>
            <ul style="list-style-type:none">
                <li>&lt;LandXML version="1.1" date="2009-11-16" time="12:29:43"&gt;</li>
            </ul>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
