<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- VERAT GENIO Report-->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
            	  <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:for-each select="GeometryProject/HorizontalAlignment">
                        <xsl:text>MOSS&#xd;</xsl:text>
                        <xsl:for-each select="VerticalAlignment">
                            <xsl:variable name="cntPVI" select="count(.//VerticalLine/VerticalStart)"/>
                            <xsl:text>VERAT,DESIGN,DESIGN&#xd;</xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:text>,</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//VerticalStart/station/@externalStation), $xslDistancePrecision)"/>
                            <xsl:text>,</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//VerticalEnd/station/@externalStation), $xslDistancePrecision)"/>
                            <xsl:text>,7=</xsl:text>
                            <xsl:value-of select="number($cntPVI + 1)"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//VerticalStart/station/@externalStation), $xslDistancePrecision)"/>
                            <xsl:text>,</xsl:text>
                            <xsl:value-of select="inr:distanceFormat(number(.//VerticalStart/@elevation), $xslDistancePrecision)"/>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
            	  </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@externalStation), $xslDistancePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@externalStation), $xslDistancePrecision)"/>
            <xsl:text>,</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>999&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle">
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@externalStation), $xslDistancePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@externalStation), $xslDistancePrecision)"/>
            <xsl:text>,</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>999&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report is only suitable for vertical circles.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>