<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold the start station rounded down to the nearest 100 -->
    <xsl:variable name="startStation" select="floor(InRoads/RoadwayVisibility/VisibilityParameters/StartStation/@internalStation div 100) * 100"/>
    <!-- Variable to hold the stop station rounded up to the nearest 100 -->
    <xsl:variable name="stopStation" select="ceiling(InRoads/RoadwayVisibility/VisibilityParameters/StopStation/@internalStation div 100) * 100"/>
    <!-- The graph displays up to 18 vertical grids -->
    <xsl:variable name="verticalGrids">
        <xsl:choose>
            <xsl:when test="$stopStation &gt;= $startStation">
                <xsl:choose>
                    <xsl:when test="($stopStation - $startStation) div 100 &lt; 19">
                        <xsl:value-of select="ceiling(($stopStation - $startStation) div 100) + 1"/>
                    </xsl:when>
                    <xsl:otherwise>18</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="($startStation - $stopStation) div 100 &lt; 19">
                        <xsl:value-of select="ceiling(($startStation - ($stopStation) div 100) + 1"/>
                    </xsl:when>
                    <xsl:otherwise>18</xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="verticalInterval">
        <xsl:choose>
            <xsl:when test="$stopStation &gt;= $startStation">
                <xsl:value-of select="ceiling(($stopStation - $startStation) div ($verticalGrids * 100)) * 100"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="ceiling(($startStation - $stopStation) div ($verticalGrids * 100)) * -100"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="actualStopStation" select="$startStation + (18 * $verticalInterval)"/>
    <!-- Variable to hold the minimum sight distance value in the raw data -->
    <xsl:variable name="minSightDistance">
        <xsl:for-each select="//Visibility[@isUnlimited = 'false']">
            <xsl:sort select="@sightDistance" data-type="number"/>
            <xsl:if test="position() = 1">
                <xsl:value-of select="@sightDistance"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <!-- Variable to hold the maximum sight distance value in the raw data -->
    <xsl:variable name="maxSightDistance">
        <xsl:for-each select="//Visibility[@isUnlimited = 'false']">
            <xsl:sort select="@sightDistance" data-type="number"/>
            <xsl:if test="position() = last()">
                <xsl:value-of select="@sightDistance"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <!-- If there are no violations, the left axis minimum will be the relaxed distance -->
    <xsl:variable name="startSightDistance">
        <xsl:choose>
            <xsl:when test="$minSightDistance &lt; //VisibilityParameters/@relaxedDistance">
                <xsl:value-of select="floor($minSightDistance div 5) * 5"/>
            </xsl:when>
            <xsl:otherwise>
                <!-- Subtract a small amount from the relaxed distance to move it off the bottom axis -->
                <xsl:value-of select="floor((//VisibilityParameters/@relaxedDistance - 5) div 5) * 5"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="stopSightDistance" select="ceiling($maxSightDistance div 5) * 5"/>
    <!-- The graph displays up to 6 horizontal grids -->
    <xsl:variable name="horizontalGrids">
        <xsl:choose>
            <xsl:when test="($stopSightDistance - $startSightDistance) div 10 &lt; 7">
                <xsl:value-of select="ceiling(($stopSightDistance - $startSightDistance) div 10) + 1"/>
            </xsl:when>
            <xsl:otherwise>6</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="horizontalInterval" select="ceiling(($stopSightDistance - $startSightDistance) div ($horizontalGrids * 5)) * 5"/>
    <!--Sight Visibility Report-->
    <xsl:output method="xml" doctype-public="-//W3C//DTD SVG 1.0//EN" doctype-system="http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd" encoding="iso-8859-1" indent="yes" media-type="image/svg" omit-xml-declaration="yes"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:element name="svg">
                    <xsl:attribute name="id">body</xsl:attribute>
                    <xsl:attribute name="width">100%</xsl:attribute>
                    <xsl:attribute name="height">4.5in</xsl:attribute>
                    <xsl:element name="style">
                        <xsl:attribute name="type">text/css</xsl:attribute>
                        .redbox{fill:#FF0000;}
                        .whitewords{fill:#FFFFFF; font-family:Arial-Bold; font-size:12pt;}
                        .label{fill:#000000; font-family:Arial; font-size:10pt;}
                    </xsl:element>
                    <xsl:element name="script">
                        <xsl:attribute name="type">text/javascript</xsl:attribute>
                        <xsl:text disable-output-escaping="yes">
                            &lt;![CDATA[
                                function HideShowTargetSD() 
                                { 
                                    SVGDoc = evt.getTarget().getOwnerDocument; 
                                    myTargetSD = SVGDoc.getElementById("targetSightDistance"); 
                                    myTargetViolation = SVGDoc.getElementById("targetViolationRange"); 
                                    CurrentVisibility = myTargetSD.getAttribute("visibility"); 
                                    if(CurrentVisibility == "visible") 
                                    { 
                                        myTargetSD.setAttribute("visibility", "hidden"); 
                                        myTargetViolation.setAttribute("visibility", "hidden"); 
                                    } 
                                    if(CurrentVisibility == "hidden") 
                                    { 
                                        myTargetSD.setAttribute("visibility", "visible"); 
                                        myTargetViolation.setAttribute("visibility", "visible"); 
                                    } 
                                } 
                                function HideShowRelaxedSD() 
                                { 
                                    SVGDoc = evt.getTarget().getOwnerDocument; 
                                    myRelaxedSD = SVGDoc.getElementById("relaxedSightDistance"); 
                                    myRelaxedViolation = SVGDoc.getElementById("relaxedViolationRange"); 
                                    CurrentVisibility = myRelaxedSD.getAttribute("visibility"); 
                                    if(CurrentVisibility == "visible") 
                                    { 
                                        myRelaxedSD.setAttribute("visibility", "hidden"); 
                                        myRelaxedViolation.setAttribute("visibility", "hidden"); 
                                    } 
                                    if(CurrentVisibility == "hidden") 
                                    { 
                                        myRelaxedSD.setAttribute("visibility", "visible"); 
                                        myRelaxedViolation.setAttribute("visibility", "visible"); 
                                    } 
                                } 
                            ]]&gt;
                        </xsl:text>
                    </xsl:element>
                    <xsl:element name="desc">Sight Visibility Graph</xsl:element>
                    <xsl:for-each select="InRoads/RoadwayVisibility">
                        <xsl:call-template name="interiorSVG"/>
                    </xsl:for-each>
                </xsl:element>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="interiorSVG">
        <svg id="interior" width="10.0in" height="4.5in" viewBox="0 0 1000 450">
            <xsl:call-template name="drawVerticalGridsAndLabels"/>
            <xsl:call-template name="drawHorizontalGridsAndLabels"/>
            <xsl:call-template name="drawViolationRanges"/>
            <xsl:call-template name="drawSightDistanceParameters"/>
            <xsl:call-template name="drawSightDistanceLines"/>
            <xsl:call-template name="drawAxes"/>
            <xsl:element name="g">
                <xsl:attribute name="id">title</xsl:attribute>
                <xsl:element name="rect">
                    <xsl:attribute name="class">redbox</xsl:attribute>
                    <xsl:attribute name="x">425</xsl:attribute>
                    <xsl:attribute name="y">400</xsl:attribute>
                    <xsl:attribute name="width">150</xsl:attribute>
                    <xsl:attribute name="height">20</xsl:attribute>
                </xsl:element>
                <xsl:element name="text">
                    <xsl:attribute name="class">whitewords</xsl:attribute>
                    <xsl:attribute name="x">455</xsl:attribute>
                    <xsl:attribute name="y">415</xsl:attribute>
                    Sight Visibility
                </xsl:element>
            </xsl:element>
        </svg>
    </xsl:template>
    <xsl:template name="drawVerticalGridsAndLabels">
        <xsl:element name="g">
            <xsl:attribute name="id">bottomAxisLabels</xsl:attribute>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">50</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">55</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 55 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">100</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">100</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">105</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 105 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + $verticalInterval), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">150</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">150</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">155</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 155 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (2 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">200</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">200</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">205</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 205 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (3 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">250</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">250</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">255</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 255 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (4 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">300</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">300</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">305</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 305 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (5 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">350</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">350</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">355</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 355 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (6 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">400</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">400</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">405</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 405 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (7 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">450</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">450</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">455</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 455 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (8 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">500</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">500</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">505</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 505 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (9 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">550</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">550</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">555</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 555 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (10 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">600</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">600</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">605</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 605 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (11 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">650</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">650</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">655</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 655 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (12 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">700</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">700</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">705</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 705 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (13 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">750</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">750</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">755</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 755 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (14 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">800</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">800</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">805</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 805 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (15 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">850</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">850</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">855</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 855 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (16 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">900</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">900</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">905</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 905 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (17 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">950</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">955</xsl:attribute>
                <xsl:attribute name="y">390</xsl:attribute>
                <xsl:attribute name="transform">rotate(-90 955 390)</xsl:attribute>
                <xsl:value-of select="inr:stationFormat(number(VisibilityParameters/StartStation/@externalStation + (18 * $verticalInterval)), $xslStationFormat, 0, string(VisibilityParameters/StartStation/@externalStationName))"/>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template name="drawHorizontalGridsAndLabels">
        <xsl:element name="g">
            <xsl:attribute name="id">leftAxisLabels</xsl:attribute>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">350</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">355</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">300</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">300</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">305</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + $horizontalInterval), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">250</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">250</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">255</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + (2 * $horizontalInterval)), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">200</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">200</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">205</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + (3 * $horizontalInterval)), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">150</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">150</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">155</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + (4 * $horizontalInterval)), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">100</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">100</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">20</xsl:attribute>
                <xsl:attribute name="y">105</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + (5 * $horizontalInterval)), 0)"/>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">50</xsl:attribute>
                <xsl:attribute name="style">stroke:#D3D3D3; stroke-width:1</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">17</xsl:attribute>
                <xsl:attribute name="y">55</xsl:attribute>
                <xsl:value-of select="inr:elevationFormat(number($startSightDistance + (6 * $horizontalInterval)), 0)"/><xsl:text>+</xsl:text>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template name="drawViolationRanges">
        <xsl:element name="g">
            <xsl:attribute name="id">violationRanges</xsl:attribute>
            <xsl:element name="rect">
                <xsl:attribute name="id">relaxedViolationRange</xsl:attribute>
                <xsl:attribute name="height"><xsl:value-of select="(VisibilityParameters/@relaxedDistance - $startSightDistance) * 50 div $horizontalInterval"/></xsl:attribute>
                <xsl:attribute name="width">900</xsl:attribute>
                <xsl:attribute name="x">50</xsl:attribute>
                <xsl:attribute name="y"><xsl:value-of select="350 - ((VisibilityParameters/@relaxedDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="style">fill:#FF0000; opacity:0.3;</xsl:attribute>
            </xsl:element>
            <xsl:element name="rect">
                <xsl:attribute name="id">targetViolationRange</xsl:attribute>
                <xsl:attribute name="height"><xsl:value-of select="(VisibilityParameters/@sightDistance - $startSightDistance) * 50 div $horizontalInterval"/></xsl:attribute>
                <xsl:attribute name="width">900</xsl:attribute>
                <xsl:attribute name="x">50</xsl:attribute>
                <xsl:attribute name="y"><xsl:value-of select="350 - ((VisibilityParameters/@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="style">fill:#FF0000; opacity:0.2;</xsl:attribute>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template name="drawSightDistanceParameters">
        <xsl:element name="g">
            <xsl:attribute name="id">sightDistanceParameters</xsl:attribute>
            <xsl:element name="line">
                <xsl:attribute name="id">targetSightDistance</xsl:attribute>
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1"><xsl:value-of select="350 - ((VisibilityParameters/@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2"><xsl:value-of select="350 - ((VisibilityParameters/@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="style">stroke:#FF0000; stroke-width:2;</xsl:attribute>
                <xsl:attribute name="visibility">visible</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">820</xsl:attribute>
                <xsl:attribute name="y"><xsl:value-of select="345 - ((VisibilityParameters/@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="onclick">HideShowTargetSD(evt)</xsl:attribute>
                Target Sight Distance
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="id">relaxedSightDistance</xsl:attribute>
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1"><xsl:value-of select="350 - ((VisibilityParameters/@relaxedDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2"><xsl:value-of select="350 - ((VisibilityParameters/@relaxedDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="style">stroke:#FF0000; stroke-width:2;</xsl:attribute>
                <xsl:attribute name="visibility">visible</xsl:attribute>
            </xsl:element>
            <xsl:element name="text">
                <xsl:attribute name="class">label</xsl:attribute>
                <xsl:attribute name="x">808</xsl:attribute>
                <xsl:attribute name="y"><xsl:value-of select="345 - ((VisibilityParameters/@relaxedDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:attribute>
                <xsl:attribute name="onclick">HideShowRelaxedSD(evt)</xsl:attribute>
                Relaxed Sight Distance
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template name="drawSightDistanceLines">
        <xsl:element name="g">
            <xsl:attribute name="id">sightDistanceLines</xsl:attribute>
            <xsl:for-each select="Visibilities/Visibility">
                <xsl:element name="line">
                    <xsl:attribute name="x1"><xsl:value-of select="50 + ((EyeStation/@internalStation - $startStation) * 50 div $verticalInterval)"/></xsl:attribute>
                    <xsl:attribute name="y1"><xsl:choose><xsl:when test="@isUnlimited = 'true'">50</xsl:when><xsl:otherwise><xsl:value-of select="350 - ((@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:otherwise></xsl:choose></xsl:attribute>
                    <xsl:attribute name="x2"><xsl:choose><xsl:when test="position() = last()"><xsl:value-of select="50 + ((../../VisibilityParameters/StopStation/@internalStation - $startStation) * 50 div $verticalInterval)"/></xsl:when><xsl:otherwise><xsl:value-of select="50 + ((following-sibling::*[1]/EyeStation/@internalStation - $startStation) * 50 div $verticalInterval)"/></xsl:otherwise></xsl:choose></xsl:attribute>
                    <xsl:attribute name="y2"><xsl:choose><xsl:when test="position() = last()">50</xsl:when><xsl:otherwise><xsl:choose><xsl:when test="following-sibling::*[1]/@isUnlimited = 'true'">50</xsl:when><xsl:otherwise><xsl:value-of select="350 - ((following-sibling::*[1]/@sightDistance - $startSightDistance) * 50 div $horizontalInterval)"/></xsl:otherwise></xsl:choose></xsl:otherwise></xsl:choose></xsl:attribute>
                    <xsl:attribute name="style">stroke:#0000FF; stroke-width:2;</xsl:attribute>
                </xsl:element>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>
    <xsl:template name="drawAxes">
        <xsl:element name="g">
            <xsl:attribute name="id">axes</xsl:attribute>
            <xsl:element name="line">
                <xsl:attribute name="id">leftAxis</xsl:attribute>
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">50</xsl:attribute>
                <xsl:attribute name="x2">50</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#636363; stroke-width:3;</xsl:attribute>
            </xsl:element>
            <xsl:element name="line">
                <xsl:attribute name="id">bottomAxis</xsl:attribute>
                <xsl:attribute name="x1">50</xsl:attribute>
                <xsl:attribute name="y1">350</xsl:attribute>
                <xsl:attribute name="x2">950</xsl:attribute>
                <xsl:attribute name="y2">350</xsl:attribute>
                <xsl:attribute name="style">stroke:#636363; stroke-width:3;</xsl:attribute>
            </xsl:element>
        </xsl:element>
    </xsl:template>
    <xsl:template name="hold">
        <g id="sightDistanceLine">
            <path d="M50 68.2413 L500 68.2413" style="fill:none;stroke:#0000FF;stroke-width:2"/>
        </g>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    The output from this report is SVG (scalable vector&#xd;</xsl:text>
        <xsl:text>    graphics) which is similar to XML in many respects.  To&#xd;</xsl:text>
        <xsl:text>    view the graph created by the output, follow these&#xd;</xsl:text>
        <xsl:text>    steps:&#xd;&#xd;</xsl:text>
        <xsl:text disable-output-escaping="yes">    1.  Save the results of the Evaluation &gt; Sight Visibil-&#xd;</xsl:text>
        <xsl:text disable-output-escaping="yes">        ity &gt; Roadway Visibility command to an XML file by&#xd;</xsl:text>
        <xsl:text>        toggling on the Create XML Report option.&#xd;&#xd;</xsl:text>
        <xsl:text disable-output-escaping="yes">    2.  Once the report is displayed, select File &gt; Save As&#xd;</xsl:text>
        <xsl:text>        from the Report Browser menu.  Leave the Save as&#xd;</xsl:text>
        <xsl:text>        type set to Text Files (*.txt) but save the output&#xd;</xsl:text>
        <xsl:text>        from this report with an extension of SVG.&#xd;&#xd;</xsl:text>
        <xsl:text>    3.  In the left pane of the Report Browser, select the&#xd;</xsl:text>
        <xsl:text disable-output-escaping="yes">        raw-xml.xsl style sheet.  Select File &gt; Open from&#xd;</xsl:text>
        <xsl:text>        the Report Browser menu, and set the Files of type&#xd;</xsl:text>
        <xsl:text>        to All Files (*.*).  Browse to the SVG file you&#xd;</xsl:text>
        <xsl:text>        saved in the previous step and the graph will be&#xd;</xsl:text>
        <xsl:text>        displayed.&#xd;&#xd;</xsl:text>
        <xsl:text>Tips&#xd;&#xd;</xsl:text>
        <xsl:text>    You may need an SVG Viewer plug-in to view SVG files on&#xd;</xsl:text>
        <xsl:text>    your workstation.  A free one is available from&#xd;</xsl:text>
        <xsl:text>    http://www.adobe.com/svg/viewer/install/main.html.&#xd;&#xd;</xsl:text>
        <xsl:text>    SVG files can also be opened in Internet Explorer by&#xd;</xsl:text>
        <xsl:text>    double-clicking the file.&#xd;&#xd;</xsl:text>
        <xsl:text>    SVG has additional commands available on the right-&#xd;</xsl:text>
        <xsl:text>    click menu in the main pane of the Report Browser or&#xd;</xsl:text>
        <xsl:text>    Internet Explorer window.  You can perform operations&#xd;</xsl:text>
        <xsl:text>    such as Zoom In and Zoom Out.  Also, if you hold the&#xd;</xsl:text>
        <xsl:text>    CTRL key down, you can window in to an area or click to&#xd;</xsl:text>
        <xsl:text>    zoom in.  If you hold the ALT key down, you can pan the&#xd;</xsl:text>
        <xsl:text>    view.  To return to the Original View, just use the&#xd;</xsl:text>
        <xsl:text>    right-click menu.&#xd;&#xd;</xsl:text>
        <xsl:text>    In addition, the graph produced by this style sheet has&#xd;</xsl:text>
        <xsl:text>    special display properties that allow to turn the&#xd;</xsl:text>
        <xsl:text>    Target and Relaxed Sight Distance lines off and on&#xd;</xsl:text>
        <xsl:text>    simply by clicking the labels.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
