<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Superelevation Station Report -->
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Superelevation Station Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Superelevation Station Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="RoadwayDesignProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Corridor:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@corridorName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@designFileName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Superelevation Station Data -->
                                <table class="margin" cellpadding="1" cellspacing="1" width="90%">
                                    <tbody>
                                        <xsl:for-each select="SuperStations">
                                            <tr>
                                                <th align="right" lang="en">Station</th>
                                            </tr>
                                            <xsl:for-each select="SuperStation">
                                                <tr>
                                                    <th align="right" valign="top">
                                                        <xsl:value-of select="inr:stationFormat(number(@externalStation), $xslStationFormat, $xslStationPrecision, string(@externalStationName))"/>
                                                    </th>
                                                    <th align="right" valign="top">
                                                        Name:&#xa0; <br/>
                                                        Cross Slope:&#xa0; <br/>
                                                        Delta G:&#xa0; <br/>
                                                        Mode:&#xa0; 
                                                    </th>
                                                    <xsl:for-each select="SuperControlValues/SuperControlValue">
                                                        <td align="left">
                                                            <strong><xsl:value-of select="@name"/></strong><br/>
                                                            <xsl:value-of select="inr:gradeFormat(number(@crossSlope), $xslGradeFormat, $xslGradePrecision)"/><br/>
                                                            <xsl:value-of select="inr:elevationFormat(number(@deltaG), $xslElevationPrecision)"/><br/>
                                                            <xsl:value-of select="@mode"/>
                                                        </td>
                                                    </xsl:for-each>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have defined superelevation for the horizontal alignment and corridor upon which 
                you wish to report by selecting the <em>Modeler &gt; Roadway Designer &gt; Superelevation 
                &gt; Create Superelevation Wizard</em> command.
            </p>
            <p class="normal1" lang="en">
                You must choose <em>All Processed Stations</em> or <em>Specified Interval</em> in the <em>
                Report At</em> group and you must select at least one <em>Superelevated Point</em> on the 
                <em>Modeler &gt; Roadway Designer &gt; Superelevation &gt; Superelevation Report</em> 
                command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
