<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <!-- Just some explanation about the creation of this stylesheet:
    We were having a problem when the point list got up around 5000 points with the XSL stack running out 
    of space if we printed one point at a time for each template call.  So this stylesheet solves this 
    problem in two ways, first by increasing the number of points output each time (the variable 
    yzCountPerTemplate stores this number, just for future reference) and by simulating a for loop.  The 
    for loop is simulated by finding a range of nodes that can be iterated through and printing out the 
    template iteratorMax number of times.  For example, teeny-nodes are the nodes in just this stylesheet.  
    By iterating through teeny-nodes, we create a for loop of about 3, so we get xyzCountPerTemplate * 
    iteratorMax * 3 points printed using this format.  Currently, this style sheet will print out up to 
    around 15 billion points (xyzCountPerTemplate * iteratorMax * xlargeNodeCount * xlargeNodeCount.)
    -->
    <xsl:include href="../format.xsl"/>
    <!-- This gives us around 15 -->
    <xsl:variable name="teeny-nodes" select="document('')/xsl:stylesheet/*"/>
    <xsl:variable name="teenyNodeCount" select="count($teeny-nodes)"/>
    <!-- This gives us around 850 -->
    <xsl:variable name="small-nodes" select="document('')//node()"/>
    <xsl:variable name="smallNodeCount" select="(count($small-nodes))"/>
    <!-- This gives us around 1700 -->
    <xsl:variable name="medium-nodes" select="document('')//node() | document('')//@*"/>
    <xsl:variable name="mediumNodeCount" select="(count($medium-nodes))"/>
    <!-- This gives us around 3700 -->
    <xsl:variable name="large-nodes" select="document('')//namespace::*"/>
    <xsl:variable name="largeNodeCount" select="(count($large-nodes))"/>
    <!-- This gives us around 5500 -->
    <xsl:variable name="xlarge-nodes" select="document('')//node() | document('')//@* | document('')//namespace::*"/>
    <xsl:variable name="xlargeNodeCount" select="(count($xlarge-nodes))"/>
    <!-- Surface Input Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text/>
                <xsl:text>;&#xd;</xsl:text>
                <xsl:text>;Surface Report&#xd;</xsl:text>
                <xsl:text>;Report Created:&#xa0; </xsl:text><xsl:value-of select="inr:date()"/><xsl:text>&#xd;</xsl:text>
                <xsl:text>;Time:&#xa0; </xsl:text><xsl:value-of select="inr:time()"/><xsl:text>&#xd;</xsl:text>
                <xsl:text>;&#xd;</xsl:text>
                <xsl:for-each select="InRoads">
                    <xsl:for-each select="Surfaces/Surface">
                        <xsl:text>;Surface Name:&#xa0; </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>;Surface Description:&#xa0; </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>;Pen Code:&#xa0; One then Zeroes&#xd;</xsl:text>
                        <xsl:text>;&#xd;</xsl:text>
                        <xsl:for-each select="Features/Feature/PointList3D">
                            <xsl:variable name="xyzCountPerTemplate" select="52"/>
                            <xsl:variable name="iteratorMax" select="10"/>
                            <xsl:variable name="templateCalls" select="(../@numberPoints div ($iteratorMax * $xyzCountPerTemplate))"/>
                            <xsl:choose>
                                <xsl:when test="($templateCalls div ($xlargeNodeCount * $xlargeNodeCount)) &gt; 4999">
                                    <xsl:message terminate="yes">
                                        XSL cannot process this many points.&#xa0; Please reduce the number of 
                                        points in your feature.
                                    </xsl:message>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:call-template name="outputCoords">
                                        <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                        <xsl:with-param name="penCode" select="1"/>
                                        <xsl:with-param name="n" select="0"/>
                                        <xsl:with-param name="iterStart" select="0"/>
                                        <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                    </xsl:call-template>
                                    <xsl:choose>
                                        <xsl:when test="$templateCalls &lt;= $xlargeNodeCount">
                                            <xsl:choose>
                                                <xsl:when test="$templateCalls &gt; $largeNodeCount">
                                                    <xsl:for-each select="$xlarge-nodes[position() &lt; $templateCalls]">
                                                        <xsl:call-template name="outputCoords">
                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                            <xsl:with-param name="penCode" select="0"/>
                                                            <xsl:with-param name="n" select="1"/>
                                                            <xsl:with-param name="iterStart" select="0"/>
                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                        </xsl:call-template>
                                                    </xsl:for-each>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:choose>
                                                        <xsl:when test="$templateCalls &gt; $mediumNodeCount">
                                                            <xsl:for-each select="$large-nodes[position() &lt; $templateCalls]">
                                                                <xsl:call-template name="outputCoords">
                                                                    <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                    <xsl:with-param name="penCode" select="0"/>
                                                                    <xsl:with-param name="n" select="1"/>
                                                                    <xsl:with-param name="iterStart" select="0"/>
                                                                    <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                </xsl:call-template>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:choose>
                                                                <xsl:when test="$templateCalls &gt; $smallNodeCount">
                                                                    <xsl:for-each select="$medium-nodes[position() &lt; $templateCalls]">
                                                                        <xsl:call-template name="outputCoords">
                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                            <xsl:with-param name="n" select="1"/>
                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                        </xsl:call-template>
                                                                    </xsl:for-each>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:for-each select="$small-nodes[position() &lt; $templateCalls ]">
                                                                        <xsl:call-template name="outputCoords">
                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                            <xsl:with-param name="n" select="1"/>
                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                        </xsl:call-template>
                                                                    </xsl:for-each>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:if test="$templateCalls &lt;= ($xlargeNodeCount * $xlargeNodeCount)">
                                                <xsl:choose>
                                                    <xsl:when test="$templateCalls &gt; ($largeNodeCount * $largeNodeCount)">
                                                        <xsl:for-each select="$xlarge-nodes[position() &lt; $templateCalls]">
                                                            <xsl:for-each select="$xlarge-nodes[position() &lt; $templateCalls]">
                                                                <xsl:call-template name="outputCoords">
                                                                    <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                    <xsl:with-param name="penCode" select="0"/>
                                                                    <xsl:with-param name="n" select="1"/>
                                                                    <xsl:with-param name="iterStart" select="0"/>
                                                                    <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                </xsl:call-template>
                                                            </xsl:for-each>
                                                        </xsl:for-each>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:choose>
                                                            <xsl:when test="$templateCalls &gt; ($mediumNodeCount * $mediumNodeCount)">
                                                                <xsl:for-each select="$large-nodes[position() &lt; $templateCalls]">
                                                                    <xsl:for-each select="$large-nodes[position() &lt; $templateCalls]">
                                                                        <xsl:call-template name="outputCoords">
                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                            <xsl:with-param name="n" select="1"/>
                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                        </xsl:call-template>
                                                                    </xsl:for-each>
                                                                </xsl:for-each>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <xsl:choose>
                                                                    <xsl:when test="$templateCalls &gt; ($smallNodeCount * $smallNodeCount)">
                                                                        <xsl:for-each select="$medium-nodes[position() &lt; $templateCalls]">
                                                                            <xsl:for-each select="$medium-nodes[position() &lt; $templateCalls]">
                                                                                <xsl:call-template name="outputCoords">
                                                                                    <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                                    <xsl:with-param name="penCode" select="0"/>
                                                                                    <xsl:with-param name="n" select="1"/>
                                                                                    <xsl:with-param name="iterStart" select="0"/>
                                                                                    <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                                </xsl:call-template>
                                                                            </xsl:for-each>
                                                                        </xsl:for-each>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <xsl:choose>
                                                                            <xsl:when test="$templateCalls &gt; ($teenyNodeCount * $xlargeNodeCount)">
                                                                                <xsl:for-each select="$small-nodes[position() &lt; $templateCalls]">
                                                                                    <xsl:for-each select="$small-nodes[position() &lt; $templateCalls]">
                                                                                        <xsl:call-template name="outputCoords">
                                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                                            <xsl:with-param name="n" select="1"/>
                                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                                        </xsl:call-template>
                                                                                    </xsl:for-each>
                                                                                </xsl:for-each>
                                                                            </xsl:when>
                                                                            <xsl:otherwise>
                                                                                <xsl:choose>
                                                                                    <xsl:when test="$templateCalls &gt; ($teenyNodeCount * $largeNodeCount)">
                                                                                        <xsl:for-each select="$teeny-nodes[position() &lt; $templateCalls]">
                                                                                            <xsl:for-each select="$xlarge-nodes[position() &lt; $templateCalls]">
                                                                                                <xsl:call-template name="outputCoords">
                                                                                                    <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                                                    <xsl:with-param name="penCode" select="0"/>
                                                                                                    <xsl:with-param name="n" select="1"/>
                                                                                                    <xsl:with-param name="iterStart" select="0"/>
                                                                                                    <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                                                </xsl:call-template>
                                                                                            </xsl:for-each>
                                                                                        </xsl:for-each>
                                                                                    </xsl:when>
                                                                                    <xsl:otherwise>
                                                                                        <xsl:choose>
                                                                                            <xsl:when test="$templateCalls &gt; ($teenyNodeCount * $mediumNodeCount)">
                                                                                                <xsl:for-each select="$teeny-nodes[position() &lt; $templateCalls]">
                                                                                                    <xsl:for-each select="$large-nodes[position() &lt; $templateCalls]">
                                                                                                        <xsl:call-template name="outputCoords">
                                                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                                                            <xsl:with-param name="n" select="1"/>
                                                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                                                        </xsl:call-template>
                                                                                                    </xsl:for-each>
                                                                                                </xsl:for-each>
                                                                                            </xsl:when>
                                                                                            <xsl:otherwise>
                                                                                                <xsl:for-each select="$teeny-nodes[position() &lt; $templateCalls]">
                                                                                                    <xsl:for-each select="$medium-nodes[position() &lt; $templateCalls]">
                                                                                                        <xsl:call-template name="outputCoords">
                                                                                                            <xsl:with-param name="list" select="concat(normalize-space(.), ' ')"/>
                                                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                                                            <xsl:with-param name="n" select="1"/>
                                                                                                            <xsl:with-param name="iterStart" select="0"/>
                                                                                                            <xsl:with-param name="maxCount" select="$iteratorMax"/>
                                                                                                        </xsl:call-template>
                                                                                                    </xsl:for-each>
                                                                                                </xsl:for-each>
                                                                                            </xsl:otherwise>
                                                                                        </xsl:choose>
                                                                                    </xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:if>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="outputCoords">
        <xsl:param name="list"/>
        <xsl:param name="penCode"/>
        <xsl:param name="n"/>
        <xsl:param name="iterStart"/>
        <xsl:param name="maxCount"/>
        <xsl:variable name="aXCoord" select="inr:getString($list, number($n))"/>
        <xsl:variable name="aYCoord" select="inr:getString($list, number($n))"/>
        <xsl:variable name="aZCoord" select="inr:getString($list, number($n))"/>
        <xsl:if test="$aXCoord">
            <xsl:value-of select="inr:columnDoubleFormat(number($aXCoord), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($aYCoord), $xslNorthingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($aZCoord), $xslElevationPrecision, 16)"/>
            <xsl:text>&#xa0; </xsl:text>
            <xsl:value-of select="$penCode"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:variable name="bXCoord" select="inr:getString($list, 1)"/>
            <xsl:variable name="bYCoord" select="inr:getString($list, 1)"/>
            <xsl:variable name="bZCoord" select="inr:getString($list, 1)"/>
            <xsl:if test="$bXCoord">
                <xsl:value-of select="inr:columnDoubleFormat(number($bXCoord), $xslEastingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number($bYCoord), $xslNorthingPrecision, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number($bZCoord), $xslElevationPrecision, 16)"/>
                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                <xsl:variable name="cXCoord" select="inr:getString($list, 1)"/>
                <xsl:variable name="cYCoord" select="inr:getString($list, 1)"/>
                <xsl:variable name="cZCoord" select="inr:getString($list, 1)"/>
                <xsl:if test="$cXCoord">
                    <xsl:value-of select="inr:columnDoubleFormat(number($cXCoord), $xslEastingPrecision, 16)"/>
                    <xsl:value-of select="inr:columnDoubleFormat(number($cYCoord), $xslNorthingPrecision, 16)"/>
                    <xsl:value-of select="inr:columnDoubleFormat(number($cZCoord), $xslElevationPrecision, 16)"/>
                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                    <xsl:variable name="dXCoord" select="inr:getString($list, 1)"/>
                    <xsl:variable name="dYCoord" select="inr:getString($list, 1)"/>
                    <xsl:variable name="dZCoord" select="inr:getString($list, 1)"/>
                    <xsl:if test="$dXCoord">
                        <xsl:value-of select="inr:columnDoubleFormat(number($dXCoord), $xslEastingPrecision, 16)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number($dYCoord), $xslNorthingPrecision, 16)"/>
                        <xsl:value-of select="inr:columnDoubleFormat(number($dZCoord), $xslElevationPrecision, 16)"/>
                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                        <xsl:variable name="eXCoord" select="inr:getString($list, 1)"/>
                        <xsl:variable name="eYCoord" select="inr:getString($list, 1)"/>
                        <xsl:variable name="eZCoord" select="inr:getString($list, 1)"/>
                        <xsl:if test="$eXCoord">
                            <xsl:value-of select="inr:columnDoubleFormat(number($eXCoord), $xslEastingPrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number($eYCoord), $xslNorthingPrecision, 16)"/>
                            <xsl:value-of select="inr:columnDoubleFormat(number($eZCoord), $xslElevationPrecision, 16)"/>
                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                            <xsl:variable name="fXCoord" select="inr:getString($list, 1)"/>
                            <xsl:variable name="fYCoord" select="inr:getString($list, 1)"/>
                            <xsl:variable name="fZCoord" select="inr:getString($list, 1)"/>
                            <xsl:if test="$fXCoord">
                                <xsl:value-of select="inr:columnDoubleFormat(number($fXCoord), $xslEastingPrecision, 16)"/>
                                <xsl:value-of select="inr:columnDoubleFormat(number($fYCoord), $xslNorthingPrecision, 16)"/>
                                <xsl:value-of select="inr:columnDoubleFormat(number($fZCoord), $xslElevationPrecision, 16)"/>
                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                <xsl:variable name="gXCoord" select="inr:getString($list, 1)"/>
                                <xsl:variable name="gYCoord" select="inr:getString($list, 1)"/>
                                <xsl:variable name="gZCoord" select="inr:getString($list, 1)"/>
                                <xsl:if test="$gXCoord">
                                    <xsl:value-of select="inr:columnDoubleFormat(number($gXCoord), $xslEastingPrecision, 16)"/>
                                    <xsl:value-of select="inr:columnDoubleFormat(number($gYCoord), $xslNorthingPrecision, 16)"/>
                                    <xsl:value-of select="inr:columnDoubleFormat(number($gZCoord), $xslElevationPrecision, 16)"/>
                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                    <xsl:variable name="hXCoord" select="inr:getString($list, 1)"/>
                                    <xsl:variable name="hYCoord" select="inr:getString($list, 1)"/>
                                    <xsl:variable name="hZCoord" select="inr:getString($list, 1)"/>
                                    <xsl:if test="$hXCoord">
                                        <xsl:value-of select="inr:columnDoubleFormat(number($hXCoord), $xslEastingPrecision, 16)"/>
                                        <xsl:value-of select="inr:columnDoubleFormat(number($hYCoord), $xslNorthingPrecision, 16)"/>
                                        <xsl:value-of select="inr:columnDoubleFormat(number($hZCoord), $xslElevationPrecision, 16)"/>
                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                        <xsl:variable name="iXCoord" select="inr:getString($list, 1)"/>
                                        <xsl:variable name="iYCoord" select="inr:getString($list, 1)"/>
                                        <xsl:variable name="iZCoord" select="inr:getString($list, 1)"/>
                                        <xsl:if test="$iXCoord">
                                            <xsl:value-of select="inr:columnDoubleFormat(number($iXCoord), $xslEastingPrecision, 16)"/>
                                            <xsl:value-of select="inr:columnDoubleFormat(number($iYCoord), $xslNorthingPrecision, 16)"/>
                                            <xsl:value-of select="inr:columnDoubleFormat(number($iZCoord), $xslElevationPrecision, 16)"/>
                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                            <xsl:variable name="jXCoord" select="inr:getString($list, 1)"/>
                                            <xsl:variable name="jYCoord" select="inr:getString($list, 1)"/>
                                            <xsl:variable name="jZCoord" select="inr:getString($list, 1)"/>
                                            <xsl:if test="$jXCoord">
                                                <xsl:value-of select="inr:columnDoubleFormat(number($jXCoord), $xslEastingPrecision, 16)"/>
                                                <xsl:value-of select="inr:columnDoubleFormat(number($jYCoord), $xslNorthingPrecision, 16)"/>
                                                <xsl:value-of select="inr:columnDoubleFormat(number($jZCoord), $xslElevationPrecision, 16)"/>
                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                <xsl:variable name="kXCoord" select="inr:getString($list, 1)"/>
                                                <xsl:variable name="kYCoord" select="inr:getString($list, 1)"/>
                                                <xsl:variable name="kZCoord" select="inr:getString($list, 1)"/>
                                                <xsl:if test="$kXCoord">
                                                    <xsl:value-of select="inr:columnDoubleFormat(number($kXCoord), $xslEastingPrecision, 16)"/>
                                                    <xsl:value-of select="inr:columnDoubleFormat(number($kYCoord), $xslNorthingPrecision, 16)"/>
                                                    <xsl:value-of select="inr:columnDoubleFormat(number($kZCoord), $xslElevationPrecision, 16)"/>
                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                    <xsl:variable name="lXCoord" select="inr:getString($list, 1)"/>
                                                    <xsl:variable name="lYCoord" select="inr:getString($list, 1)"/>
                                                    <xsl:variable name="lZCoord" select="inr:getString($list, 1)"/>
                                                    <xsl:if test="$lXCoord">
                                                        <xsl:value-of select="inr:columnDoubleFormat(number($lXCoord), $xslEastingPrecision, 16)"/>
                                                        <xsl:value-of select="inr:columnDoubleFormat(number($lYCoord), $xslNorthingPrecision, 16)"/>
                                                        <xsl:value-of select="inr:columnDoubleFormat(number($lZCoord), $xslElevationPrecision, 16)"/>
                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                        <xsl:variable name="mXCoord" select="inr:getString($list, 1)"/>
                                                        <xsl:variable name="mYCoord" select="inr:getString($list, 1)"/>
                                                        <xsl:variable name="mZCoord" select="inr:getString($list, 1)"/>
                                                        <xsl:if test="$mXCoord">
                                                            <xsl:value-of select="inr:columnDoubleFormat(number($mXCoord), $xslEastingPrecision, 16)"/>
                                                            <xsl:value-of select="inr:columnDoubleFormat(number($mYCoord), $xslNorthingPrecision, 16)"/>
                                                            <xsl:value-of select="inr:columnDoubleFormat(number($mZCoord), $xslElevationPrecision, 16)"/>
                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                            <xsl:variable name="nXCoord" select="inr:getString($list, 1)"/>
                                                            <xsl:variable name="nYCoord" select="inr:getString($list, 1)"/>
                                                            <xsl:variable name="nZCoord" select="inr:getString($list, 1)"/>
                                                            <xsl:if test="$nXCoord">
                                                                <xsl:value-of select="inr:columnDoubleFormat(number($nXCoord), $xslEastingPrecision, 16)"/>
                                                                <xsl:value-of select="inr:columnDoubleFormat(number($nYCoord), $xslNorthingPrecision, 16)"/>
                                                                <xsl:value-of select="inr:columnDoubleFormat(number($nZCoord), $xslElevationPrecision, 16)"/>
                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                <xsl:variable name="oXCoord" select="inr:getString($list, 1)"/>
                                                                <xsl:variable name="oYCoord" select="inr:getString($list, 1)"/>
                                                                <xsl:variable name="oZCoord" select="inr:getString($list, 1)"/>
                                                                <xsl:if test="$oXCoord">
                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($oXCoord), $xslEastingPrecision, 16)"/>
                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($oYCoord), $xslNorthingPrecision, 16)"/>
                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($oZCoord), $xslElevationPrecision, 16)"/>
                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                    <xsl:variable name="pXCoord" select="inr:getString($list, 1)"/>
                                                                    <xsl:variable name="pYCoord" select="inr:getString($list, 1)"/>
                                                                    <xsl:variable name="pZCoord" select="inr:getString($list, 1)"/>
                                                                    <xsl:if test="$pXCoord">
                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($pXCoord), $xslEastingPrecision, 16)"/>
                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($pYCoord), $xslNorthingPrecision, 16)"/>
                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($pZCoord), $xslElevationPrecision, 16)"/>
                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                        <xsl:variable name="qXCoord" select="inr:getString($list, 1)"/>
                                                                        <xsl:variable name="qYCoord" select="inr:getString($list, 1)"/>
                                                                        <xsl:variable name="qZCoord" select="inr:getString($list, 1)"/>
                                                                        <xsl:if test="$qXCoord">
                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($qXCoord), $xslEastingPrecision, 16)"/>
                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($qYCoord), $xslNorthingPrecision, 16)"/>
                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($qZCoord), $xslElevationPrecision, 16)"/>
                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                            <xsl:variable name="rXCoord" select="inr:getString($list, 1)"/>
                                                                            <xsl:variable name="rYCoord" select="inr:getString($list, 1)"/>
                                                                            <xsl:variable name="rZCoord" select="inr:getString($list, 1)"/>
                                                                            <xsl:if test="$rXCoord">
                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($rXCoord), $xslEastingPrecision, 16)"/>
                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($rYCoord), $xslNorthingPrecision, 16)"/>
                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($rZCoord), $xslElevationPrecision, 16)"/>
                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                <xsl:variable name="sXCoord" select="inr:getString($list, 1)"/>
                                                                                <xsl:variable name="sYCoord" select="inr:getString($list, 1)"/>
                                                                                <xsl:variable name="sZCoord" select="inr:getString($list, 1)"/>
                                                                                <xsl:if test="$sXCoord">
                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($sXCoord), $xslEastingPrecision, 16)"/>
                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($sYCoord), $xslNorthingPrecision, 16)"/>
                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($sZCoord), $xslElevationPrecision, 16)"/>
                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                    <xsl:variable name="tXCoord" select="inr:getString($list, 1)"/>
                                                                                    <xsl:variable name="tYCoord" select="inr:getString($list, 1)"/>
                                                                                    <xsl:variable name="tZCoord" select="inr:getString($list, 1)"/>
                                                                                    <xsl:if test="$tXCoord">
                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($tXCoord), $xslEastingPrecision, 16)"/>
                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($tYCoord), $xslNorthingPrecision, 16)"/>
                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($tZCoord), $xslElevationPrecision, 16)"/>
                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                        <xsl:variable name="uXCoord" select="inr:getString($list, 1)"/>
                                                                                        <xsl:variable name="uYCoord" select="inr:getString($list, 1)"/>
                                                                                        <xsl:variable name="uZCoord" select="inr:getString($list, 1)"/>
                                                                                        <xsl:if test="$uXCoord">
                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($uXCoord), $xslEastingPrecision, 16)"/>
                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($uYCoord), $xslNorthingPrecision, 16)"/>
                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($uZCoord), $xslElevationPrecision, 16)"/>
                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                            <xsl:variable name="vXCoord" select="inr:getString($list, 1)"/>
                                                                                            <xsl:variable name="vYCoord" select="inr:getString($list, 1)"/>
                                                                                            <xsl:variable name="vZCoord" select="inr:getString($list, 1)"/>
                                                                                            <xsl:if test="$vXCoord">
                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($vXCoord), $xslEastingPrecision, 16)"/>
                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($vYCoord), $xslNorthingPrecision, 16)"/>
                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($vZCoord), $xslElevationPrecision, 16)"/>
                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                <xsl:variable name="wXCoord" select="inr:getString($list, 1)"/>
                                                                                                <xsl:variable name="wYCoord" select="inr:getString($list, 1)"/>
                                                                                                <xsl:variable name="wZCoord" select="inr:getString($list, 1)"/>
                                                                                                <xsl:if test="$wXCoord">
                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($wXCoord), $xslEastingPrecision, 16)"/>
                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($wYCoord), $xslNorthingPrecision, 16)"/>
                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($wZCoord), $xslElevationPrecision, 16)"/>
                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                    <xsl:variable name="xXCoord" select="inr:getString($list, 1)"/>
                                                                                                    <xsl:variable name="xYCoord" select="inr:getString($list, 1)"/>
                                                                                                    <xsl:variable name="xZCoord" select="inr:getString($list, 1)"/>
                                                                                                    <xsl:if test="$xXCoord">
                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($xXCoord), $xslEastingPrecision, 16)"/>
                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($xYCoord), $xslNorthingPrecision, 16)"/>
                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($xZCoord), $xslElevationPrecision, 16)"/>
                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                        <xsl:variable name="yXCoord" select="inr:getString($list, 1)"/>
                                                                                                        <xsl:variable name="yYCoord" select="inr:getString($list, 1)"/>
                                                                                                        <xsl:variable name="yZCoord" select="inr:getString($list, 1)"/>
                                                                                                        <xsl:if test="$yXCoord">
                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($yXCoord), $xslEastingPrecision, 16)"/>
                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($yYCoord), $xslNorthingPrecision, 16)"/>
                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($yZCoord), $xslElevationPrecision, 16)"/>
                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                            <xsl:variable name="zXCoord" select="inr:getString($list, 1)"/>
                                                                                                            <xsl:variable name="zYCoord" select="inr:getString($list, 1)"/>
                                                                                                            <xsl:variable name="zZCoord" select="inr:getString($list, 1)"/>
                                                                                                            <xsl:if test="$zXCoord">
                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($zXCoord), $xslEastingPrecision, 16)"/>
                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($zYCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($zZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                <xsl:variable name="a1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                <xsl:variable name="a1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                <xsl:variable name="a1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                <xsl:if test="$a1XCoord">
                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($a1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($a1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($a1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                    <xsl:variable name="b1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                    <xsl:variable name="b1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                    <xsl:variable name="b1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                    <xsl:if test="$b1XCoord">
                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($b1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($b1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($b1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                        <xsl:variable name="c1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                        <xsl:variable name="c1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                        <xsl:variable name="c1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                        <xsl:if test="$c1XCoord">
                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($c1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($c1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($c1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                            <xsl:variable name="d1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                            <xsl:variable name="d1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                            <xsl:variable name="d1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                            <xsl:if test="$d1XCoord">
                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($d1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($d1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($d1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                <xsl:variable name="e1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                <xsl:variable name="e1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                <xsl:variable name="e1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                <xsl:if test="$e1XCoord">
                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($e1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($e1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($e1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                    <xsl:variable name="f1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                    <xsl:variable name="f1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                    <xsl:variable name="f1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                    <xsl:if test="$f1XCoord">
                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($f1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($f1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($f1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                        <xsl:variable name="g1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                        <xsl:variable name="g1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                        <xsl:variable name="g1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                        <xsl:if test="$g1XCoord">
                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($g1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($g1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($g1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                            <xsl:variable name="h1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                            <xsl:variable name="h1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                            <xsl:variable name="h1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                            <xsl:if test="$h1XCoord">
                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($h1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($h1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($h1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                <xsl:variable name="i1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                <xsl:variable name="i1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                <xsl:variable name="i1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                <xsl:if test="$i1XCoord">
                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($i1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($i1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($i1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                    <xsl:variable name="j1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                    <xsl:variable name="j1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                    <xsl:variable name="j1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                    <xsl:if test="$j1XCoord">
                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($j1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($j1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($j1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                        <xsl:variable name="k1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                        <xsl:variable name="k1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                        <xsl:variable name="k1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                        <xsl:if test="$k1XCoord">
                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($k1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($k1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($k1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                            <xsl:variable name="l1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                            <xsl:variable name="l1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                            <xsl:variable name="l1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                            <xsl:if test="$l1XCoord">
                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($l1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($l1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($l1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                <xsl:variable name="m1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                <xsl:variable name="m1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                <xsl:variable name="m1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                <xsl:if test="$m1XCoord">
                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($m1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($m1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($m1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                    <xsl:variable name="n1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                    <xsl:variable name="n1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                    <xsl:variable name="n1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                    <xsl:if test="$n1XCoord">
                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($n1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($n1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($n1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                        <xsl:variable name="o1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                        <xsl:variable name="o1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                        <xsl:variable name="o1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                        <xsl:if test="$o1XCoord">
                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($o1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($o1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($o1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                            <xsl:variable name="p1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                            <xsl:variable name="p1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                            <xsl:variable name="p1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                            <xsl:if test="$p1XCoord">
                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($p1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($p1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($p1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                <xsl:variable name="q1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                <xsl:variable name="q1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                <xsl:variable name="q1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                <xsl:if test="$q1XCoord">
                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($q1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($q1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($q1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                    <xsl:variable name="r1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                    <xsl:variable name="r1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                    <xsl:variable name="r1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                    <xsl:if test="$r1XCoord">
                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($r1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($r1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($r1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                        <xsl:variable name="s1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                        <xsl:variable name="s1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                        <xsl:variable name="s1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                        <xsl:if test="$s1XCoord">
                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($s1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($s1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($s1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                            <xsl:variable name="t1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                            <xsl:variable name="t1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                            <xsl:variable name="t1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                            <xsl:if test="$t1XCoord">
                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($t1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($t1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($t1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                <xsl:variable name="u1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                <xsl:variable name="u1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                <xsl:variable name="u1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                <xsl:if test="$u1XCoord">
                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($u1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($u1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($u1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                    <xsl:variable name="v1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                    <xsl:variable name="v1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                    <xsl:variable name="v1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                    <xsl:if test="$v1XCoord">
                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($v1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($v1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($v1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                        <xsl:variable name="w1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                        <xsl:variable name="w1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                        <xsl:variable name="w1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                        <xsl:if test="$w1XCoord">
                                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($w1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($w1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                            <xsl:value-of select="inr:columnDoubleFormat(number($w1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                            <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                            <xsl:variable name="x1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                            <xsl:variable name="x1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                            <xsl:variable name="x1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                            <xsl:if test="$x1XCoord">
                                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($x1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($x1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                                <xsl:value-of select="inr:columnDoubleFormat(number($x1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                                <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                                <xsl:variable name="y1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                <xsl:variable name="y1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                <xsl:variable name="y1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                <xsl:if test="$y1XCoord">
                                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($y1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($y1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                                    <xsl:value-of select="inr:columnDoubleFormat(number($y1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                                    <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                                    <xsl:variable name="z1XCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                    <xsl:variable name="z1YCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                    <xsl:variable name="z1ZCoord" select="inr:getString($list, 1)"/>
                                                                                                                                                                                                                    <xsl:if test="$z1XCoord">
                                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($z1XCoord), $xslEastingPrecision, 16)"/>
                                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($z1YCoord), $xslNorthingPrecision, 16)"/>
                                                                                                                                                                                                                        <xsl:value-of select="inr:columnDoubleFormat(number($z1ZCoord), $xslElevationPrecision, 16)"/>
                                                                                                                                                                                                                        <xsl:text>&#xa0; 0&#xd;</xsl:text>
                                                                                                                                                                                                                        <xsl:if test="$iterStart &lt; ($maxCount - 1)">
                                                                                                                                                                                                                            <xsl:call-template name="outputCoords">
                                                                                                                                                                                                                            <xsl:with-param name="list" select="$list"/>
                                                                                                                                                                                                                            <xsl:with-param name="penCode" select="0"/>
                                                                                                                                                                                                                            <xsl:with-param name="n" select="1"/>
                                                                                                                                                                                                                            <xsl:with-param name="iterStart" select="($iterStart) + 1"/>
                                                                                                                                                                                                                            <xsl:with-param name="maxCount" select="$maxCount"/>
                                                                                                                                                                                                                            </xsl:call-template>
                                                                                                                                                                                                                        </xsl:if>
                                                                                                                                                                                                                    </xsl:if>
                                                                                                                                                                                                                </xsl:if>
                                                                                                                                                                                                            </xsl:if>
                                                                                                                                                                                                        </xsl:if>
                                                                                                                                                                                                    </xsl:if>
                                                                                                                                                                                                </xsl:if>
                                                                                                                                                                                            </xsl:if>
                                                                                                                                                                                        </xsl:if>
                                                                                                                                                                                    </xsl:if>
                                                                                                                                                                                </xsl:if>
                                                                                                                                                                            </xsl:if>
                                                                                                                                                                        </xsl:if>
                                                                                                                                                                    </xsl:if>
                                                                                                                                                                </xsl:if>
                                                                                                                                                            </xsl:if>
                                                                                                                                                        </xsl:if>
                                                                                                                                                    </xsl:if>
                                                                                                                                                </xsl:if>
                                                                                                                                            </xsl:if>
                                                                                                                                        </xsl:if>
                                                                                                                                    </xsl:if>
                                                                                                                                </xsl:if>
                                                                                                                            </xsl:if>
                                                                                                                        </xsl:if>
                                                                                                                    </xsl:if>
                                                                                                                </xsl:if>
                                                                                                            </xsl:if>
                                                                                                        </xsl:if>
                                                                                                    </xsl:if>
                                                                                                </xsl:if>
                                                                                            </xsl:if>
                                                                                        </xsl:if>
                                                                                    </xsl:if>
                                                                                </xsl:if>
                                                                            </xsl:if>
                                                                        </xsl:if>
                                                                    </xsl:if>
                                                                </xsl:if>
                                                            </xsl:if>
                                                        </xsl:if>
                                                    </xsl:if>
                                                </xsl:if>
                                            </xsl:if>
                                        </xsl:if>
                                    </xsl:if>
                                </xsl:if>
                            </xsl:if>
                        </xsl:if>
                    </xsl:if>
                </xsl:if>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one feature in the Features&#xd;</xsl:text>
        <xsl:text>    list on the Tools &gt; XML Reports &gt; Surfaces command&#xd;</xsl:text>
        <xsl:text>    to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must also toggle on the Include Feature Points&#xd;</xsl:text>
        <xsl:text>    option.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function splits a space-delimited string into tokens
            // stringList - String to get tokenized
            var stringArray;        //static array of tokens; should be reset for every PointList3D
            var num = 0;            //index into the token array
            var curVal = 0;         //used to indicate that the stringArray should be reset
            
            function stringSplit(stringList)
            {
                stringArray = stringList.split(" ");
            }
            // This Function parses out a string into tokens
            // strList - Original space delimited list
            // val - 0 or 1 depending on if its the first template or successive templates
            function getString(stringList, val)
            {
                //This should reset the list for each Point3dList
                if (val == 0)
                {
                    if (curVal > 2)
                        curVal = 0;
                }
                
                //This is for the first 3 entries
                if (curVal < 3)
                {
                    if (curVal == 0)
                    {
                        stringSplit(stringList);
                        num = 0;
                    }
                    else
                    {
                        num++;
                    }
                    
                    curVal++;
                    return stringArray[num];
                }
                num++;
                if (! isNaN(stringArray[num]))
                    return stringArray[num];
                    
                return "";
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
