<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Horizontal Element Tabling -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Horizontal Element Tabling</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/HorizontalAnnotationTable">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Horizontal Element Tabling</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <table class="margin">
                                <tr>
                                    <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                    <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor"/></td>
                                    <td class="sidepad" align="right" lang="en" style="font-size: 80%">
                                        <strong>Note:&#xa0; </strong>All units in this report are in
                                        <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                        <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                        unless specified otherwise.
                                    </td>
                                </tr>
                            </table>
                            <hr/>
                            <!-- Horizontal Line Table -->
                            <table class="margin" border="1" cellpadding="2" cellspacing="0">
                                <thead style="display:table-header-group">
                                    <tr><th colspan="3" lang="en">Line Table</th></tr>
                                    <tr>
                                        <th lang="en" valign="bottom">Name</th>
                                        <th lang="en" valign="bottom">Length</th>
                                        <th lang="en" valign="bottom">Direction</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="TableLine/HorizontalLine">
                                        <tr>
                                            <td><xsl:value-of select="../@name"/></td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                            </td>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                            <br/>
                            <!-- Horizontal Circle Table -->
                            <table class="margin" border="1" cellpadding="2" cellspacing="0">
                                <thead style="display:table-header-group">
                                    <tr><th colspan="8" lang="en">Curve Table</th></tr>
                                    <tr>
                                        <th lang="en" valign="bottom">Name</th>
                                        <th lang="en" valign="bottom">Radius</th>
                                        <th lang="en" valign="bottom">Arc</th>
                                        <th lang="en" valign="bottom">Chord</th>
                                        <th lang="en" valign="bottom">Tangent</th>
                                        <th lang="en" valign="bottom">Middle</th>
                                        <th lang="en" valign="bottom">External</th>
                                        <th lang="en" valign="bottom">Chord</th>
                                    </tr>
                                    <tr>
                                        <th lang="en" valign="bottom">&#xa0;</th>
                                        <th lang="en" valign="bottom">&#xa0;</th>
                                        <th lang="en" valign="bottom">Length</th>
                                        <th lang="en" valign="bottom">Length</th>
                                        <th lang="en" valign="bottom">Length</th>
                                        <th lang="en" valign="bottom">Ordinate</th>
                                        <th lang="en" valign="bottom">Distance</th>
                                        <th lang="en" valign="bottom">Direction</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="TableCircle/HorizontalCircle">
                                        <tr>
                                            <td><xsl:value-of select="../@name"/></td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@tangentLength), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@middleOrdinate), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@externalDistance), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                            </td>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                            <br/>
                            <!-- Horizontal Spiral Table -->
                            <table class="margin" border="1" cellpadding="2" cellspacing="0">
                                <thead style="display:table-header-group">
                                    <tr>
                                        <th colspan="8" lang="en">Spiral Table</th>
                                    </tr>
                                    <tr>
                                        <th lang="en" valign="bottom">Name</th>
                                        <th lang="en" valign="bottom">Theta</th>
                                        <th lang="en" valign="bottom">Entrance Radius</th>
                                        <th lang="en" valign="bottom">Spiral Length</th>
                                        <th lang="en" valign="bottom">Long Tangent</th>
                                        <th lang="en" valign="bottom">Xs</th>
                                        <th lang="en" valign="bottom">Long Chord</th>
                                        <th lang="en" valign="bottom">P</th>
                                    </tr>
                                    <tr>
                                        <th lang="en">&#xa0;</th>
                                        <th lang="en">Chord Direction</th>
                                        <th lang="en">Exit Radius</th>
                                        <th lang="en">Spiral Constant</th>
                                        <th lang="en">Short Tangent</th>
                                        <th lang="en">Ys</th>
                                        <th lang="en">&#xa0;</th>
                                        <th lang="en">Ks</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="TableSpiral/HorizontalSpiral">
                                        <tr>
                                            <td><xsl:value-of select="../@name"/></td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@longTangent), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@xs), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td>&#xa0;</td>
                                            <td class="sidepad" align="right" nowrap="nowrap">
                                                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@aConstant), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@shortTangent), $xslDistancePrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@ys), $xslDistancePrecision)"/>
                                            </td>
                                            <td>&#xa0;</td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
                                            </td>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                            <br/>
                            <!-- Point Table -->
                            <table class="margin" border="1" cellpadding="2" cellspacing="0">
                                <thead style="display:table-header-group">
                                    <tr>
                                        <th colspan="6" lang="en">Point Table</th>
                                    </tr>
                                    <tr>
                                        <th lang="en">Name</th>
                                        <th lang="en">Northing</th>
                                        <th lang="en">Easting</th>
                                        <th lang="en">Elevation</th>
                                        <th lang="en">Description</th>
                                        <th lang="en">Style</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="TablePoint/GeometryPoint">
                                        <tr>
                                            <td>
                                                <xsl:choose>
                                                    <xsl:when test="../@name &gt; 0">
                                                        <xsl:value-of select="../@name"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                </xsl:choose>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                            </td>
                                            <td class="sidepad" align="right">
                                                <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslEastingPrecision)"/>
                                            </td>
                                            <td>
                                                <xsl:choose>
                                                    <xsl:when test="@description">
                                                        <xsl:value-of select="@description"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                </xsl:choose>
                                            </td>
                                            <td><xsl:value-of select="@style"/></td>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                            <br/>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment or one Cogo point on the <em>Main</em> 
                tab of the <em>Geometry &gt; View Geometry &gt; Horizontal Annotation</em> command.
            </p>
            <p class="normal1" lang="en">
                You must select <em>Assigned</em> or <em>Active</em> in the <em>Apply Style</em> group and 
                the selected style, whether it is the assigned style or the active, must have the <em>Allow 
                Tabling</em> option toggled on for the element type you wish to table.&#xa0; For example, 
                if you wish to table spirals, select the <em>Tools &gt; Style Manager</em> command and find 
                your style.&#xa0; Select the <em>Edit</em> button and navigate to the <em>Geometry Feature 
                &gt; Spirals &gt; Alternate</em> leaf and toggle on the <em>Allow Tabling</em> 
                option.&#xa0; Do this for each element type in each feature style that you plan to table.
            </p>
            <p class="normal1" lang="en">
                You must select either <em>Basic Element Information</em> or <em>All Element 
                Information</em> on the <em>Tabling</em> tab of the <em>Geometry &gt; View Geometry &gt; 
                Horizontal Annotation</em> command to get results from this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                You can place the results of your report into your MicroStation design file by highlighting 
                the text you wish to copy in the <em>Report Browser</em>, keying in CTRL+C, and then keying 
                in CTRL+V in your design file.
            </p>
            <p class="normal1" lang="en">
                You may have to edit the text once placed in your design file to correct the 
                alignment.&#xa0; You will have better results if you select a "text only" style sheet and 
                choose a monospaced font in MicroStation.
            </p>
            <p class="normal1" lang="en">
                Also, many of the fonts delivered within the MicroStation resource file have mapped the 
                degree symbol (&#xb0;) to something else.&#xa0; You can either edit the text and replace 
                whatever it mapped to with the caret (^), which will then display properly as the degree 
                symbol, or you can select a standard TrueType font.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
