<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Slab Elevation Intermediate Points Only Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Slab Elevation Intermediate Points Only Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Slab Elevation Intermediate Points Only Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Slab Elevation Data -->
                                <xsl:for-each select="BridgeCenterLine">
                                    <table class="margin" width="90%">
                                        <colgroup>
                                            <col width="17%"/>
                                            <col width="17%"/>
                                            <col width="17%"/>
                                            <col width="16%"/>
                                            <col width="17%"/>
                                            <col width="16%"/>
                                        </colgroup>
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom">Station</th>
                                                <th class="underline" lang="en" valign="bottom">Left Shoulder</th>
                                                <th class="underline" lang="en" valign="bottom">Left Edge of<br/>Pavement</th>
                                                <th class="underline" lang="en" valign="bottom">Centerline</th>
                                                <th class="underline" lang="en" valign="bottom">Right Edge of<br/>Pavement</th>
                                                <th class="underline" lang="en" valign="bottom">Right Shoulder</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="SlabElevations">
                                                <tr>
                                                    <xsl:apply-templates/>
                                                </tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="SlabElevation[@stationGrouping = '1']">
        <td align="right" style="white-space:nowrap">
            <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat, $xslStationPrecision, string(station/@externalStationName))"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
        </td>
    </xsl:template>
    <xsl:template match="SlabElevation[@stationGrouping = '2' or @stationGrouping = '3' or @stationGrouping = '4']">
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
        </td>
    </xsl:template>
    <xsl:template match="SlabElevation[@stationGrouping = '5']">
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
        </td>
        <tr/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia and 
                abutments/piers for the bridge.
            </p>
            <p class="normal1" lang="en">
                On the <em>Main</em> tab of the <em>Bridge &gt; Bridge Reports</em> command, you must also 
                select the <em>Bridge Surface</em>.&#xa0; On the <em>Slab Elevations</em> tab of the <em>
                Bridge &gt; Bridge Reports</em> command, you must toggle on the <em>Include Slab 
                Elevations</em> and <em>Include Abutment/Pier Lines</em> options.&#xa0; You must also 
                specify the <em>Left Slab Fascia, Left Edge of Pavement, Right Edge of Pavement</em> and 
                <em>Right Slab Fascia</em> on the <em>Slab Elevations</em> tab to get satisfactory results 
                from this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                It is advisable to set the <em>Station Limits</em> to match the start and end abutments of 
                the bridge if the alignment extends beyond the abutments.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
