<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- U-Beam Haunch Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">U-Beam Haunch Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">U-Beam Haunch Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- U-Beam Haunch Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <xsl:for-each select="Girders/Girder/UBeam">
                                            <tbody>
                                                <xsl:for-each select="UBeamHaunch">
                                                    <tr>
                                                        <tr>
                                                            <td colspan="6">&#xa0;</td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Girder Name:</th>
                                                            <td align="right"><xsl:value-of select="../../@name"/></td>
                                                            <th align="left" lang="en">( Span: </th>
                                                            <td align="left"><xsl:value-of select="../../@startSpan"/></td>
                                                            <th align="left" lang="en"> Beam: </th>
                                                            <td align="left"><xsl:value-of select="../../@number"/><strong> )</strong></td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Beam Type:</th>
                                                            <td align="right"><xsl:value-of select="../../@description"/></td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Slab Thickness:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@slabThickness),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Beam Top Flange Width:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@topFlangeWidth),$xslDistancePrecision)"/>
                                                            </td>
                                                        </tr> 
                                                        <tr>
                                                            <th align="left" lang="en">Beam Depth:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@beamDepth),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Bearing Pad Thickness:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@bearingPadThickness),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Width of Pedestal:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@widthOfPedestal),$xslDistancePrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Camber:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@camber),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Dead Load Deflection:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@deadLoadDeflection),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Center Line Span Minimum Haunch:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@centerLineMinimumHaunch),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Vertical Ordinate Back Bearing:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateBackBearingLeft),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateBackBearingRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Vertical Ordinate Maximum:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateMaximumLeft),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateMaximumRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Vertical Ordinate Ahead Bearing:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateAheadBearingLeft),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@verticalOrdinateAheadBearingRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Minimum Required Haunch:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@minimumRequiredHaunchLeft),$xslElevationPrecision)"/>
                                                            </td>  
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@minimumRequiredHaunchRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Minimum Used Haunch:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@minimumUsedHaunch),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Maximum Calculated Haunch:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@maximumCalculatedHaunch),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">X at Point A:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@XAtPointA),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">X at Point B:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@XAtPointB),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Z:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@leftZ),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@rightZ),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Bearing Deduct:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@bearingDeduct),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Back Beam Seat Elevation:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@backBeamSeatLeft),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@backBeamSeatRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                        <tr>
                                                            <th align="left" lang="en">Ahead Beam Seat Elevation:</th>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@aheadBeamSeatLeft),$xslElevationPrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:elevationFormat(number(@aheadBeamSeatRight),$xslElevationPrecision)"/>
                                                            </td>
                                                        </tr>
                                                    </tr>
                                                </xsl:for-each>
                                            </tbody>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia, 
                abutments/piers, bearing lines, girders and verticals for the bridge.
            </p>
            <p class="normal1" lang="en">
                You must also select the <em>Bridge &gt; Bridge Reports</em> command to get results from 
                this report.
            </p>
            <p class="normal1" lang="en">This report is only suitable for U-Beams.</p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
