<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>

    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY HORIZONTAL ALIGNMENT REVIEW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:value-of select="inr:columnFormat('STATION',47)"/>
                        <xsl:value-of select="inr:columnFormat('NORTHING',20)"/>
                        <xsl:value-of select="inr:columnFormat('EASTING',20)"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="HorizontalLine">
        <xsl:text>Element: Linear</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(Start/station/@externalStationName)), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(Start/@northing), $xslNorthingPrecision), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(Start/@easting), $xslEastingPrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <xsl:value-of select="inr:columnFormat('EQNBK',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(@backEquation)), 32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision), 20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision), 20)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:value-of select="inr:columnFormat('EQNAHD',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(@aheadEquation)),32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision),20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision),20)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:for-each>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(End/@northing), $xslNorthingPrecision),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(End/@easting), $xslEastingPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangential Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangential Length:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template match="HorizontalCircle">
        <xsl:text>Element: Circular</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(Start/station/@externalStationName)), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(Start/@northing), $xslNorthingPrecision), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(Start/@easting), $xslEastingPrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="PI">
            <xsl:value-of select="inr:columnFormat(inr:pointType(string(PI/@pointType)),15)"/>
            <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(PI/@name),10)"/><xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName)),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(PI/@northing), $xslNorthingPrecision),20)"/>
            <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(PI/@easting), $xslEastingPrecision),20)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Center/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Center/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(Center/@northing), $xslNorthingPrecision),40)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(Center/@easting), $xslEastingPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <xsl:value-of select="inr:columnFormat('EQNBK',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(@backEquation)), 32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision), 20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision), 20)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:value-of select="inr:columnFormat('EQNAHD',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(@aheadEquation)),32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision),20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision),20)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:for-each>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(End/@northing), $xslNorthingPrecision),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(End/@easting), $xslEastingPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radius:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@radius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Delta:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod),20)"/>
        <xsl:if test="@rotationDirection='cw'"><xsl:text> Right</xsl:text></xsl:if>
        <xsl:if test="@rotationDirection='ccw'"><xsl:text> Left</xsl:text></xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="../../@curvatureDefinition = 'arc'">
            <xsl:value-of select="inr:columnFormat('Degree of Curvature(Arc):',27)"/>
        </xsl:if>
        <xsl:if test="../../@curvatureDefinition = 'chord'">
            <xsl:value-of select="inr:columnFormat('Degree of Curvature(Chord):',27)"/>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(inr:angularFormat(number(@degreeOfCurve), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@tangentLength), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Chord:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@chord), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Middle Ordinate:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@middleOrdinate), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('External:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@externalDistance), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radial Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Chord Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radial Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template match="HorizontalSpiral">
        <xsl:text>Element: </xsl:text>
        <xsl:choose>
            <xsl:when test="@compound = 'false'">
                <xsl:value-of select="@type"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>Compound </xsl:text>
                <xsl:value-of select="@type"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(Start/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(Start/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(Start/station/@externalStationName)), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(Start/@northing), $xslNorthingPrecision), 20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(Start/@easting), $xslEastingPrecision), 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(PI/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(PI/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(PI/@northing), $xslNorthingPrecision),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(PI/@easting), $xslEastingPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="StationEquation">
            <xsl:for-each select="StationEquation">
                <xsl:value-of select="inr:columnFormat('EQNBK',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@backStation), $xslStationFormat, $xslStationPrecision, string(@backEquation)), 32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision), 20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision), 20)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:value-of select="inr:columnFormat('EQNAHD',15)"/>
                <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(@aheadStation), $xslStationFormat, $xslStationPrecision, string(@aheadEquation)),32)"/>
                <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision),20)"/>
                <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision),20)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:for-each>
        </xsl:if>
        <xsl:value-of select="inr:columnFormat(inr:pointType(string(End/@pointType)),15)"/>
        <xsl:text>(</xsl:text><xsl:value-of select="inr:columnFormat(string(End/@name),10)"/><xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName)),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:northingFormat(number(End/@northing), $xslNorthingPrecision),20)"/>
        <xsl:value-of select="inr:columnFormat(inr:eastingFormat(number(End/@easting), $xslEastingPrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Entrance Radius:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@startRadius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Exit Radius:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@endRadius), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Length:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@length), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Angle:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod),20)"/>
        <xsl:if test="@rotationDirection='cw'"> Right</xsl:if>
        <xsl:if test="@rotationDirection = 'ccw'"> Left</xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Constant:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@aConstant), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Long Tangent:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@longTangent), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Short Tangent:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@shortTangent), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Long Chord:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@longChord), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Xs:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@xs), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Ys:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@ys), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('P:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@p), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('K:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:distanceFormat(number(@ks), $xslDistancePrecision),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radial Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Chord Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Radial Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat('Tangent Direction:',27)"/>
        <xsl:value-of select="inr:columnFormat(inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod),20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
       <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one Civil horizontal geometry element to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2012 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
