<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>

    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Vertical Alignment Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Vertical Alignment Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">&#xa0; </th>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>

                                <xsl:for-each select="HorizontalAlignment[VerticalAlignment]">
                                    <table class="margin" width="75%">
                                <colgroup span="4">
                                    <col width="23%"/>
                                    <col width="18%"/>
                                    <col width="31%"/>
                                    <col width="28%"/>
                                </colgroup>
                                        <thead>
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br/>Horizontal Alignment:</th>
                                                <td align="left" colspan="2" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Description:</th>
                                                <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Style:</th>
                                                <td align="left" colspan="2"><xsl:value-of select="@style"/></td>
                                            </tr>
                                        </thead>
                                        <tbody>

                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:</th>
                                                    <td align="left" colspan="2" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Description:</th>
                                                    <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Style:</th>
                                                    <td align="left" colspan="2"><xsl:value-of select="@style"/></td>
                                                </tr>
                                                <tr>
                                                    <th/>
                                                    <th/>
                                                    <th align="right" class="underline" lang="en">Station</th>
                                                    <th align="right" class="underline" lang="en">Elevation</th>
                                                </tr>
                                                <xsl:apply-templates/>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="VerticalLine">
        <tr>
            <td align="left" colspan="4" lang="en"><br/>Element: Linear</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalStart/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <tr>
                <td align="right" colspan="2" lang="en">EQNBK</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="2" lang="en">EQNAHD</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalEnd/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="VerticalSymmetricalParabola">
        <tr>
            <td align="left" colspan="4" lang="en"><br/>Element: Symmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalStart/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(PVI/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <tr>
                <td align="right" colspan="2" lang="en">EQNBK</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="2" lang="en">EQNAHD</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalEnd/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(TurningPoint/@pointType))"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
           <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
           </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">r = (g2 - g1) / L:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@rateOfChange), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K = l / (g2 - g1):</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@kValue), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Middle Ordinate:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="VerticalUnsymmetricalParabola">
        <tr>
            <td align="left" colspan="4" lang="en"><br/>Element: Unsymmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalStart/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(PVI/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(PVCC/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVCC/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVCC/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <tr>
                <td align="right" colspan="2" lang="en">EQNBK</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="2" lang="en">EQNAHD</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalEnd/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(TurningPoint/@pointType))"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startVerticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endVerticalCurveLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">r = (g2 - g1) / L:</td>
            <td align="right">
                Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startRateOfChange), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endRateOfChange), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K = l / (g2 - g1):</td>
            <td align="right">
                Entrance: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@startKValue), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                Exit: &#xa0;<xsl:value-of select="inr:distanceFormat(number(@endKValue), $xslDistancePrecision)"/>
           </td>
        </tr>
        <tr>
           <td align="right" colspan="2" lang="en">Middle Ordinate:</td>
           <td align="right">
               <xsl:value-of select="inr:distanceFormat(number(@midOrdinate), $xslDistancePrecision)"/>
           </td>
       </tr>
    </xsl:template>

    <xsl:template match="VerticalCircle">
        <tr>
            <td align="left" colspan="4" lang="en"><br/>Element: Circular</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalStart/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(PVI/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalCenter/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalCenter/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalCenter/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalCenter/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <tr>
                <td align="right" colspan="2" lang="en">EQNBK</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="2" lang="en">EQNAHD</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalEnd/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(TurningPoint/@pointType))"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="VerticalClothoid">
        <tr>
            <td align="left" colspan="4" lang="en"><br/>Element: Clothoid</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalStart/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(PVI/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="StationEquation">
            <tr>
                <td align="right" colspan="2" lang="en">EQNBK</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@backStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@backEquation))"/>
                </td>
            </tr>
            <tr>
                <td align="right" colspan="2" lang="en">EQNAHD</td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(StationEquation/@aheadStation), $xslStationFormat, $xslStationPrecision, string(StationEquation/@aheadEquation))"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(VerticalEnd/@pointType))"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
        </tr>
        <xsl:if test="TurningPoint">
            <tr>
                <td align="right" colspan="2"><xsl:value-of select="inr:pointType(string(TurningPoint/@pointType))"/></td>
                <td align="right">
                    <xsl:value-of select="inr:stationFormat(number(TurningPoint/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(TurningPoint/station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:elevationFormat(number(TurningPoint/@elevation), $xslElevationPrecision)"/>
                </td>
            </tr>
        </xsl:if>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Angle:</td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td>
                <xsl:if test="@rotationDirection='cw'">Right</xsl:if>
                <xsl:if test="@rotationDirection = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Short Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@shortTangent), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Chord:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@longChord), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Xs:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@xs), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Ys:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ys), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">P:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@p), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">K:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@ks), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Grade:</td>
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select at least one Civil vertical geometry element to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2012 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
