<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
  <xsl:include href="../format.xsl"/>
  <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
  <xsl:template match="/">
    <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
        <title lang="en">Ballast Report</title>
      </head>
      <body>
        <xsl:choose>
          <xsl:when test="$xslShowHelp = 'true'">
            <xsl:call-template name="StyleSheetHelp"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:for-each select="InRoads">
              <center>
                <h2 lang="en">Ballast Report</h2>
                <p lang="en">
                  Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                  Time:&#xa0; <xsl:value-of select="inr:time()"/>
                </p>
              </center>
              <xsl:for-each select="BallastReport">
                <table cellpadding="2" class="margin" width="90%">
                  <tbody>
                    <tr>
                      <th align="right" lang="en">Project:&#xa0; </th>
                      <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                    </tr>
                    <tr>
                      <th align="right" lang="en">Description:&#xa0; </th>
                      <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                    </tr>
                    <tr>
                      <th align="right" lang="en">File Name:&#xa0; </th>
                      <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                    </tr>
                    <tr>
                      <th align="right" lang="en">Last Revised:&#xa0; </th>
                      <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                    </tr>
                    <tr>
                      <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                      <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                      <td align="right" lang="en" style="font-size: 80%">
                        <strong>Note:&#xa0; </strong>All units in this report are in
                        <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                        <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                        unless specified otherwise.
                      </td>
                    </tr>
                  </tbody>
                </table>
                <hr/>
                <tr>
                  <table cellpadding="1" width="100%">
                    <td colspan="16">
                      <table width="100%" border="1">
                        <tr align="center">
                          <th colspan="5">General</th>
                          <th colspan="4">Track 1</th>
                          <th colspan="3">Subgrade</th>
                          <th colspan="4">Track 2</th>
                        </tr>
                        <tr align="center">
                          <th>Label</th>
                          <th>Station</th>
                          <th>ZP theorical</th>
                          <th>Radius</th>
                          <th>Cant (mm)</th>
                          <th colspan="4">
                              <table border="1">
                                <tbody>
                                    <tr>
                                        <th colspan="2">Left rail</th>
                                        <th colspan="2">Right rail</th>
                                    </tr>
                                    <tr>
                                        <th>Ballast depth (mm)</th>
                                        <th>Z Rail</th>
                                        <th>Ballast depth (mm)</th>
                                        <th>Z Rail</th>
                                    </tr>
                                </tbody>
                            </table>
                          </th>
                          <th>Left Slope (%)</th>
                          <th>Point P</th>
                          <th>Right Slope (%)</th>
                          <th colspan="4">
                              <table border="1">
                                <tbody>
                                    <tr>
                                        <th colspan="2">Left rail</th>
                                        <th colspan="2">Right rail</th>
                                    </tr>
                                    <tr>
                                        <th>Ballast depth (mm)</th>
                                        <th>Z Rail</th>
                                        <th>Ballast depth (mm)</th>
                                        <th>Z Rail</th>
                                    </tr>
                                </tbody>
                            </table>
                          </th>
                        </tr>
                        <xsl:for-each select="BallastPoints/BallastPoint">
                          <tr>
                            <td align="left">
                                <xsl:if test="@pointName  = ''">
                                    <xsl:if test="@pointType != 'POT'">
                                        <xsl:if test="@pointType != 'POC'">
                                            <xsl:if test="@pointType != 'POS'">
                                              <xsl:value-of select="@type"/>
                                            </xsl:if>
                                        </xsl:if>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:if test="@pointName != ''">
                                  <xsl:value-of select="@pointName"/>
                                </xsl:if>
                            </td>                              
                            <td align="right">                              
                              <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat,$xslStationPrecision, string(station/@externalStationName))"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(@ZPtheorical), $xslElevationPrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(@cant), 0)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track1/LeftRail/@BallastDepthRgmm), 0)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track1/LeftRail/@ZRailRg), $xslElevationPrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track1/RightRail/@BallastDepthRdmm), 0)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track1/RightRail/@ZRailRd), $xslElevationPrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:gradeFormat(number(subgrade/@leftSlope), $xslGradeFormat, $xslGradePrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(@ZPtheorical), $xslElevationPrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:gradeFormat(number(subgrade/@rightSlope), $xslGradeFormat, $xslGradePrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track2/LeftRail/@BallastDepthRgmm), 0)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track2/LeftRail/@ZRailRg), $xslElevationPrecision)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track2/RightRail/@BallastDepthRdmm), 0)"/>
                            </td>
                            <td align="right">
                              <xsl:value-of select="inr:distanceFormat(number(Track2/RightRail/@ZRailRd), $xslElevationPrecision)"/>
                            </td>
                          </tr>
                        </xsl:for-each>
                      </table>
                    </td>
                  </table>
                </tr>
              </xsl:for-each>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>
  <xsl:template name="StyleSheetHelp">
    <div class="section1">
      <h4 lang="en">Notes</h4>
      <p class="normal1" lang="en">
        Run EGIS > Tools > Ballast Reports.
      </p>
      <p class="small" lang="en">
        <em>&#xa9; 2010 Bentley Systems, Inc</em>
      </p>
    </div>
  </xsl:template>
</xsl:stylesheet>
