<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Trimble Custom Cross Section Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
            	  <xsl:for-each select="InRoads/GeometryProject">
            	      <xsl:text/>
            	      <xsl:text>TNEL</xsl:text>
            	      <xsl:value-of select="inr:TNELdate()"/>
            	      <xsl:text> TRIMBLE LTD Custom xsection report format&#xd;</xsl:text>
            	      <xsl:text>Chainage followed by Alignment Name, Easting, Northing, Offset, Level&#xd;</xsl:text>
            	      <xsl:for-each select="//StationOffsetPoint">
            	          <xsl:sort select="centerLinePoint/point/station/@internalStation" data-type="number"/>
            	          <xsl:if test="not(centerLinePoint/point/station/@internalStation = preceding-sibling::*/centerLinePoint/point/station/@internalStation)">
                	          <xsl:text>Chainage: </xsl:text>
                	          <xsl:value-of select="inr:stationFormat(number(centerLinePoint/point/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(centerLinePoint/point/station/@externalStationName))"/>
                	          <xsl:text>&#xd;</xsl:text>
            	          </xsl:if>
                        <xsl:choose>
                            <xsl:when test="string-length(@offsetAlignmentName) &gt; 15">
                                <xsl:value-of select="substring(@offsetAlignmentName, 1, 15)"/>
                            </xsl:when>
                            <xsl:when test="string-length(@offsetAlignmentName) &lt; 15">
                                <xsl:value-of select="@offsetAlignmentName"/>
                                <xsl:value-of select="substring('&#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0;', 1, 15 - string-length(@offsetAlignmentName))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@offsetAlignmentName"/>
                            </xsl:otherwise>
                        </xsl:choose>
            	          <xsl:value-of select="inr:columnDoubleFormat(number(offsetPoint/@easting), 3, 14)"/>
            	          <xsl:value-of select="inr:columnDoubleFormat(number(offsetPoint/@northing), 3, 14)"/>
            	          <xsl:value-of select="inr:columnDoubleFormat(number(@firstOffset), 3, 10)"/>
            	          <xsl:value-of select="inr:columnDoubleFormat(number(offsetPoint/@elevation), 3, 10)"/>
            	          <xsl:text>&#xd;</xsl:text>
            	      </xsl:for-each>
            	  </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must create station offset points for this report&#xd;</xsl:text>
        <xsl:text>    by selecting either Tools &gt; XML Reports &gt; Station Base&#xd;</xsl:text>
        <xsl:text>    or Tools &gt; XML Reports &gt; Station Offset.  You must&#xd;</xsl:text>
        <xsl:text>    include at least one horizontal alignment or one&#xd;</xsl:text>
        <xsl:text>    feature on the General leaf in the From fields.  You&#xd;</xsl:text>
        <xsl:text>    must also include at least one horizontal alignment on&#xd;</xsl:text>
        <xsl:text>    the Horizontal Alignments leaf or one feature on the&#xd;</xsl:text>
        <xsl:text>    Features leaf.  You must choose at least one option on&#xd;</xsl:text>
        <xsl:text>    the Include leaf (Horizontal On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Horizontal Event Points, Vertical On-Alignment Points,&#xd;</xsl:text>
        <xsl:text>    Vertical Event Points or Interval.)&#xd;&#xd;</xsl:text>
        <xsl:text>    If you wish to include Vertical Event Points or you&#xd;</xsl:text>
        <xsl:text>    wish to use an Offset, you must use the Tools &gt; XML&#xd;</xsl:text>
        <xsl:text>    Reports &gt; Station Offset command rather than the Tools&#xd;</xsl:text>
        <xsl:text>    &gt; XML Reports &gt; Station Base command.&#xd;&#xd;</xsl:text>
        <xsl:text>    Station Limits only apply to computed data, ie, event&#xd;</xsl:text>
        <xsl:text>    points by interval.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date and formats it for TNEL Timestamp.
            function TNELdate()
            {
                var today = new Date();
                var month = today.getMonth() + 1;
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                var minutes = today.getMinutes();
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                if (month < 10)
                {
                    month = "0" + month;
                }
                return dayOfMonth + "-" + month + "-" + year;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
