<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Horizontal Elements Table Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="GeometryProject">
                                <!-- Horizontal Alignment Data -->
                                <table border="1" cellpadding="2" cellspacing="0" width="100%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th lang="en" valign="bottom">Point Type</th>
                                            <th lang="en" valign="bottom">Station</th>
                                            <th lang="en" valign="bottom">Northing</th>
                                            <th lang="en" valign="bottom">Easting</th>
                                            <th lang="en" valign="bottom">Radius</th>
                                            <th lang="en" valign="bottom">Length</th>
                                            <th lang="en" valign="bottom">Tangent</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="HorizontalAlignment">
                                            <tr>
                                                <th align="left" colspan="2" lang="en">Aligment Name:</th>
                                                <td colspan="10"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="left" colspan="2" lang="en">Description:</th>
                                                <xsl:choose>
                                                    <xsl:when test="@description">
                                                        <td colspan="10"><xsl:value-of select="@description"/></td>
                                                    </xsl:when>
                                                    <xsl:otherwise><td colspan="10">&#xa0;</td></xsl:otherwise>
                                                </xsl:choose>
                                            </tr>
                                            <xsl:for-each select="HorizontalElements">
                                                <xsl:apply-templates/>
                                            </xsl:for-each>
                                            <tr><td colspan="12">&#xa0;</td></tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="HorizontalLine">
        <tr>
            <td align="center"><xsl:value-of select="Start/@type"/></td>
            <td align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr>
            <td align="center"><xsl:value-of select="End/@type"/></td>
            <td align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr/>
    </xsl:template>
    <!-- Horizontal Circular Data -->
    <xsl:template match="HorizontalCircle">
        <tr>
            <td align="center"><xsl:value-of select="Start/@type"/></td>
            <td align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr>
            <td align="center"><xsl:value-of select="PI/@type"/></td>
            <td align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:stationFormat(number(PI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PI/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PI/@easting), $xslEastingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@tangentLength), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="center"><xsl:value-of select="End/@type"/></td>
            <td align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
            </td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
            <td>&#xa0;</td>
        </tr>
        <tr/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.  This
                report does not support spiralized alignments.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
