<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variables to hold unit strings -->
    <xsl:variable name="linearUnit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ft</xsl:when>
            <xsl:otherwise>m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit1">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">sq ft</xsl:when>
            <xsl:otherwise>sq m</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="areaUnit2">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">ac</xsl:when>
            <xsl:otherwise>ha</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Traverse Edit ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <!-- Report Title -->
                    <xsl:text>Traverse Edit Report&#xd;&#xd;</xsl:text>
                    <!-- Project Data -->
                    <xsl:for-each select="GeometryProject">
                        <xsl:text>Project:     </xsl:text><xsl:value-of select="@name"/>
                        <!-- Horizontal Alignment Data -->
                        <xsl:for-each select="HorizontalAlignment">
                            <xsl:text>&#xd;Alignment:   </xsl:text><xsl:value-of select="@name"/>
                            <xsl:text>&#xd;Description: </xsl:text><xsl:value-of select="@description"/>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                            <xsl:apply-templates/>
                            <xsl:if test="@northingClosingError">
                                <xsl:text>Northing Error:    </xsl:text>
                                <xsl:value-of select="inr:distanceFormat(number(@northingClosingError), $xslDistancePrecision)"/>
                                <xsl:text> </xsl:text><xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;Easting Error:     </xsl:text>
                                <xsl:value-of select="inr:distanceFormat(number(@eastingClosingError), $xslDistancePrecision)"/>
                                <xsl:text> </xsl:text><xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;Closing Direction: </xsl:text>
                                <xsl:value-of select="inr:directionFormat(number(@closingDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                <xsl:text>&#xd;Closing Distance:  </xsl:text>
                                <xsl:value-of select="inr:distanceFormat(number(@closingDistance), $xslDistancePrecision)"/>
                                <xsl:text> </xsl:text><xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;Closed Area:       </xsl:text>
                                <xsl:value-of select="inr:areaFormat(number(@area), $xslAreaPrecision)"/>
                                <xsl:text> </xsl:text><xsl:value-of select="$areaUnit1"/>
                                <xsl:text> (</xsl:text>
                                <xsl:choose>
                                    <xsl:when test="//@linearUnits = 'Imperial'">
                                        <td align="right">
                                            <xsl:value-of select="inr:areaFormat(number(@area div 43560), $xslAreaPrecision)"/>
                                        </td>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <td align="right">
                                            <xsl:value-of select="inr:areaFormat(number(@area div 10000), $xslAreaPrecision)"/>
                                        </td>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:text> </xsl:text><xsl:value-of select="$areaUnit2"/><xsl:text>)</xsl:text>
                                <xsl:text>&#xd;Perimeter:         </xsl:text>
                                <xsl:value-of select="inr:distanceFormat(number(@perimeter), $xslDistancePrecision)"/>
                                <xsl:text> </xsl:text><xsl:value-of select="$linearUnit"/>
                                <xsl:text>&#xd;Precision:         </xsl:text>
                                <xsl:value-of select="inr:distanceFormat(number(@closingPrecision), $xslDistancePrecision)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:value-of select="inr:columnFormat(string(Start/@type), 6)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 41)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@elevation), $xslElevationPrecision, 13)"/>
        <xsl:text>&#xd; </xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 22)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 20)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@type), 6)"/>
            <xsl:text> (</xsl:text>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 41)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), $xslElevationPrecision, 13)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:value-of select="inr:columnFormat(string(Start/@type), 6)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Start/@name">
                <xsl:value-of select="inr:columnFormat(string(Start/@name), 8)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 41)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@elevation), $xslElevationPrecision, 13)"/>
        <xsl:text>&#xd;       Radius:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 28)"/>
        <xsl:text>&#xd;       Delta:</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 30)"/>
        <xsl:text>&#xd;       Length:</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 28)"/>
        <xsl:if test="@tangentLength != -1.">
            <xsl:text>&#xd;       Chord:</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(@chord), $xslDistancePrecision, 29)"/>
            <xsl:text>&#xd;       Tangent:</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(@tangentLength), $xslDistancePrecision, 27)"/>
            <xsl:text>&#xd;       Middle Ordinate:</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(@middleOrdinate), $xslDistancePrecision, 19)"/>
            <xsl:text>&#xd;       External:</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(@externalDistance), $xslDistancePrecision, 26)"/>
            <xsl:text>&#xd;       </xsl:text>
            <xsl:value-of select="inr:directionFormat(number(@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            <xsl:text> (Radial)</xsl:text>
        </xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:value-of select="inr:columnFormat(string(Center/@type), 6)"/>
        <xsl:text> (</xsl:text>
        <xsl:choose>
            <xsl:when test="Center/@name">
                <xsl:value-of select="inr:columnFormat(string(Center/@name), 8)"/>
            </xsl:when>
            <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
        </xsl:choose>
        <xsl:text>)</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@northing), $xslNorthingPrecision, 41)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Center/@elevation), $xslElevationPrecision, 13)"/>
        <xsl:text>&#xd;       </xsl:text>
        <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text> (Chord )</xsl:text>
        <xsl:text>&#xd;       </xsl:text>
        <xsl:value-of select="inr:directionFormat(number(@radialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text> (Radial)&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:value-of select="inr:columnFormat(string(End/@type), 6)"/>
            <xsl:text> (</xsl:text>
            <xsl:choose>
                <xsl:when test="End/@name">
                    <xsl:value-of select="inr:columnFormat(string(End/@name), 8)"/>
                </xsl:when>
                <xsl:otherwise><xsl:value-of select="concat('    ', '    ')"/></xsl:otherwise>
            </xsl:choose>
            <xsl:text>)</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 41)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@elevation), $xslElevationPrecision, 13)"/>
            <xsl:text>&#xd;&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    This report may be used with data from the Geometry &gt;&#xd;</xsl:text>
        <xsl:text>    Utilities &gt; Traverse Edit command or the Tools &gt;&#xd;</xsl:text>
        <xsl:text>    XML Reports &gt; Geometry command.&#xd;&#xd;</xsl:text>
        <xsl:text>    To use the Traverse Edit command, first select Tools &gt;&#xd;</xsl:text>
        <xsl:text>    Application Add-Ins and toggle on the Traverse Edit&#xd;</xsl:text>
        <xsl:text>    Add-In.  Generate the data by selecting the Report&#xd;</xsl:text>
        <xsl:text>    button.&#xd;&#xd;</xsl:text>
        <xsl:text>    If you are using the Geometry reports command, you must&#xd;</xsl:text>
        <xsl:text>    include at least one horizontal alignment in the&#xd;</xsl:text>
        <xsl:text>    Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Note:  This report is not suitable for alignments&#xd;</xsl:text>
        <xsl:text>    containing spirals.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2007 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
