<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Vertical Alignment Points with XY Coordinates Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Vertical Alignment Points with XY Coordinates Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Vertical Alignment Points with XY Coordinates Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment[VerticalAlignment]">
                                    <table class="margin" width="90%">
                                        <thead>
                                            <tr>
                                                <th align="right" colspan="2" lang="en"><br/>Horizontal Alignment:</th>
                                                <td align="left" colspan="4" valign="bottom"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Description:</th>
                                                <td align="left" colspan="4"><xsl:value-of select="@description"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Horizontal Style:</th>
                                                <td align="left" colspan="4"><xsl:value-of select="@style"/></td>
                                            </tr>
                                            <tr>
                                                <th colspan="6">&#xa0;</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <!-- Vertical Alignment Data -->
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:</th>
                                                    <td align="left" colspan="4" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Description:</th>
                                                    <td align="left" colspan="4"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Style:</th>
                                                    <td align="left" colspan="4"><xsl:value-of select="@style"/></td>
                                                </tr>
                                                <tr>
                                                    <th colspan="2"/>
                                                    <th align="right" class="underline" lang="en">Station</th>
                                                    <th align="right" class="underline" lang="en">Elevation</th>
                                                    <th align="right" class="underline" lang="en">Northing</th>
                                                    <th align="right" class="underline" lang="en">Easting</th>
                                                </tr>
                                                <xsl:apply-templates/>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <tr>
            <td align="left" colspan="6" lang="en"><br/>Element: Linear</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalStart/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalStart/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalEnd/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalEnd/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <tr>
            <td align="left" colspan="6" lang="en"><br/>Element: Symmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalStart/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalStart/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PVI/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PVI/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalEnd/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalEnd/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <tr>
            <td align="left" colspan="6" lang="en"><br/>Element: Unsymmetrical Parabola</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalStart/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalStart/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
          <td align="right">
            <xsl:value-of select="inr:northingFormat(number(PVI/@northing), $xslNorthingPrecision)"/>
          </td>
          <td align="right">
            <xsl:value-of select="inr:eastingFormat(number(PVI/@easting), $xslEastingPrecision)"/>
          </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVCC/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVCC/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVCC/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PVCC/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PVCC/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
          <td align="right">
            <xsl:value-of select="inr:northingFormat(number(VerticalEnd/@northing), $xslNorthingPrecision)"/>
          </td>
          <td align="right">
            <xsl:value-of select="inr:eastingFormat(number(VerticalEnd/@easting), $xslEastingPrecision)"/>
          </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle">
        <tr>
            <td align="left" colspan="6" lang="en"><br/>Element: Circular</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalStart/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalStart/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
          <td align="right">
            <xsl:value-of select="inr:northingFormat(number(PVI/@northing), $xslNorthingPrecision)"/>
          </td>
          <td align="right">
            <xsl:value-of select="inr:eastingFormat(number(PVI/@easting), $xslEastingPrecision)"/>
          </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalCenter/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalCenter/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalCenter/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalCenter/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalCenter/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalCenter/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalEnd/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalEnd/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Vertical Alignment Clothoid Data -->
    <xsl:template match="VerticalClothoid">
        <tr>
            <td align="left" colspan="6" lang="en"><br/>Element: Clothoid</td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalStart/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalStart/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalStart/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="PVI/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(PVI/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(PVI/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(PVI/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(PVI/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(PVI/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2"><xsl:value-of select="VerticalEnd/@type"/></td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(VerticalEnd/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(VerticalEnd/@easting), $xslEastingPrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Include Vertical Alignments</em> option and 
                select either <em>All</em> or <em>Active</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
