<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Centerline Coordinates Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Centerline Coordinates Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Centerline Coordinates Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Traverse Alignment:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="//StakeoutPoint/@alignment"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Stakeout Point Data -->
                                <table class="margin" cellpadding="2" cellspacing="2" width="80%">
                                    <tbody>
                                        <xsl:for-each select="HorizontalAlignment[StakeoutPoints/StakeoutPoint]">
                                            <tr>
                                                <th align="right" colspan="2" lang="en">Centerline Alignment:</th>
                                                <td align="left" colspan="4"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Type</th>
                                                <th class="underline" lang="en">Northing</th>
                                                <th class="underline" lang="en">Easting</th>
                                                <th class="underline" lang="en">Elevation</th>
                                            </tr>
                                            <xsl:for-each select="StakeoutPoints/StakeoutPoint">
                                                <tr>
                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:stationFormat(number(foresightPoint/point/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(foresightPoint/point/station/@externalStationName))"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="foresightPoint/point/@type"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(foresightPoint/point/@northing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(foresightPoint/point/@easting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(foresightPoint/point/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                        <xsl:for-each select="CogoPoints[StakeoutPoints]">
                                            <tr>
                                                <th align="left" colspan="2" lang="en">Cogo Points:</th>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Easting (X)</th>
                                                <th class="underline" lang="en">Northing (Y)</th>
                                                <th class="underline" lang="en">Elevation (Z)</th>
                                            </tr>
                                            <xsl:for-each select="StakeoutPoints/StakeoutPoint">
                                                <tr>
                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:stationFormat(number(foresightPoint/point/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(foresightPoint/point/station/@externalStationName))"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(foresightPoint/point/@easting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(foresightPoint/point/@northing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(foresightPoint/point/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must create stakeout points for this report by selecting <em>Tools &gt; XML Reports 
                &gt; Stakeout</em>.
            </p>
            <p class="normal1" lang="en">
                You must include either a horizontal alignment or a backsight and foresight point on the 
                <em>General</em> leaf in the <em>From</em> group.
            </p>
            <p class="normal1" lang="en">
                You must toggle on at least one option in the <em>Include Horizontal Points</em> group or 
                key-in a value in the <em>Interval</em> option on the <em>General</em> leaf.
            </p>
            <p class="normal1" lang="en">
                You must also include at least one horizontal alignment on the <em>Horizontal Alignments
                </em> leaf or one cogo point on the <em>Cogo Points</em> leaf or one feature on the <em>
                Features</em> leaf.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
