<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique fixed points -->
    <xsl:variable name="uniqueFixedPointName" select="//SurveyPointList/SurveyPoint[not (@name = preceding-sibling::SurveyPoint/@name)][@type = '0']/@name"/>
    <!-- Unique fixed point codes -->
    <xsl:variable name="uniqueFixedPointCode" select="//SurveyPointList/SurveyPoint[not (@code = preceding-sibling::SurveyPoint/@code)][@type = '0']/@code"/>
    <!-- Mismatched Codes on Fixed Points Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title>Mismatched Codes on Fixed Points Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Mismatched Codes on Fixed Points Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="SurveyFieldbook">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Fieldbook:&#xa0; </th>
                                            <td colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:choose>
                                                    <xsl:when test="//@surveyLinearUnits = 'Metric'">meters</xsl:when>
                                                    <xsl:otherwise>feet</xsl:otherwise>
                                                </xsl:choose>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Survey Point Data -->
                                <table class="margin" cellpadding="2" cellspacing="2" width="80%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Point<br/>Name</th>
                                            <th class="underline" lang="en" valign="bottom">Northing</th>
                                            <th class="underline" lang="en" valign="bottom">Easting</th>
                                            <th class="underline" colspan="2" lang="en" valign="bottom">Mismatched Codes</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:variable name="set1" select="//SurveyObservation[@name = $uniqueFixedPointName]"/>
                                        <xsl:variable name="set2" select="//SurveyObservation[@code = $uniqueFixedPointCode]"/>
                                        <xsl:variable name="result" select="$set1[count(. | $set2) != count($set2)]"/>
                                        <xsl:for-each select="$result">
                                            <tr>
                                                <td class="sidepad" valign="top"><xsl:value-of select="@name"/></td>
                                                <td class="sidepad" align="right" valign="top">
                                                    <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                                </td>
                                                <td class="sidepad" align="right" valign="top">
                                                    <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                                </td>
                                                <td class="sidepad">
                                                    <strong>Code at Station <xsl:value-of select="../@name"/>:&#xa0; </strong>
                                                </td>
                                                <td class="sidepad">
                                                    <xsl:value-of select="@code"/>
                                                </td>
                                            </tr>
                                            <tr>
                                                <td colspan="3">&#xa0;</td>
                                                <td class="sidepad">
                                                    <strong>Code at Station <xsl:value-of select="following::SurveyObservation[@name = current()/@name]/../@name"/>:&#xa0; </strong>
                                                </td>
                                                <td class="sidepad">
                                                    <xsl:value-of select="following::SurveyObservation[@name = current()/@name]/@code"/>
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select at least one fieldbook in the <em>Survey &gt; XML Report</em> command to 
                get results from this report.
            </p>
            <p class="normal1" lang="en">
                Your fieldbook must contain data for a complete report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
