<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Single Table ASCII Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/HorizontalAnnotationTable">
                    <xsl:text/>
                    <xsl:text>                                  Horizontal Elements Table&#xd;&#xd;</xsl:text>
                    <xsl:text>              Direction /&#xd;</xsl:text>
                    <xsl:text>  Name      Chord Direction     Length         Delta         Radius         Theta&#xd;</xsl:text>
                    <xsl:text>--------   -----------------  -----------  --------------  -----------  --------------&#xd;&#xd;</xsl:text>
                    <xsl:for-each select="*">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:choose>
            <xsl:when test="string-length(../@name) &gt; 8">
                <xsl:value-of select="substring(../@name, 1, 8)"/>
            </xsl:when>
            <xsl:when test="string-length(../@name) &lt; 8">
                <xsl:value-of select="substring('        ', 1, 8 - string-length(../@name))"/>
                <xsl:value-of select="../@name"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="../@name"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@direction), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 20)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 13)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:choose>
            <xsl:when test="string-length(../@name) &gt; 8">
                <xsl:value-of select="substring(../@name, 1, 8)"/>
            </xsl:when>
            <xsl:when test="string-length(../@name) &lt; 8">
                <xsl:value-of select="substring('        ', 1, 8 - string-length(../@name))"/>
                <xsl:value-of select="../@name"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="../@name"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 20)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 13)"/>
        <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 16)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @radius), $xslDistancePrecision, 13)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 13)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:choose>
            <xsl:when test="string-length(../@name) &gt; 8">
                <xsl:value-of select="substring(../@name, 1, 8)"/>
            </xsl:when>
            <xsl:when test="string-length(../@name) &lt; 8">
                <xsl:value-of select="substring('        ', 1, 8 - string-length(../@name))"/>
                <xsl:value-of select="../@name"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="../@name"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 20)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 13)"/>
        <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 45)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment or&#xd;</xsl:text>
        <xsl:text>    one Cogo point on the Main tab of the Geometry &gt; View&#xd;</xsl:text>
        <xsl:text>    Geometry &gt; Horizontal Annotation command.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select Assigned or Active in the Apply Style&#xd;</xsl:text>
        <xsl:text>    group and the selected style, regardless of whether it&#xd;</xsl:text>
        <xsl:text>    is the assigned style or the active, must have the&#xd;</xsl:text>
        <xsl:text>    Allow Tabling option toggled on for the element type&#xd;</xsl:text>
        <xsl:text>    you wish to table.  For example, if you wish to table&#xd;</xsl:text>
        <xsl:text>    spirals, select the Tools &gt; Style Manager command and&#xd;</xsl:text>
        <xsl:text>    find your style.  Select the Edit button and navigate&#xd;</xsl:text>
        <xsl:text>    to the Geometry Feature &gt; Spirals &gt; Alternate leaf and&#xd;</xsl:text>
        <xsl:text>    toggle on the Allow Tabling option.  Do this for each&#xd;</xsl:text>
        <xsl:text>    element type in each feature style that you plan to&#xd;</xsl:text>
        <xsl:text>    table.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select either Basic Element Information or All&#xd;</xsl:text>
        <xsl:text>    Element Information on the Tabling tab of the Geometry&#xd;</xsl:text>
        <xsl:text>    &gt; View Geometry &gt; Horizontal Annotation command to get&#xd;</xsl:text>
        <xsl:text>    results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>Tips&#xd;&#xd;</xsl:text>
        <xsl:text>    You can place the results of your report into your&#xd;</xsl:text>
        <xsl:text>    MicroStation design file by highlighting the text you&#xd;</xsl:text>
        <xsl:text>    wish to copy in the Report Browser, keying in CTRL+C,&#xd;</xsl:text>
        <xsl:text>    and then keying in CTRL+V in your design file.&#xd;&#xd;</xsl:text>
        <xsl:text>    You may have to edit the text once placed in your&#xd;</xsl:text>
        <xsl:text>    design file to correct the alignment.  You will have&#xd;</xsl:text>
        <xsl:text>    better results if you select a "text only" style sheet&#xd;</xsl:text>
        <xsl:text>    and choose a monospaced font in MicroStation.&#xd;&#xd;</xsl:text>
        <xsl:text>    Also, many of the fonts delivered within the&#xd;</xsl:text>
        <xsl:text>    MicroStation resource file have mapped the degree&#xd;</xsl:text>
        <xsl:text>    symbol (&#xb0;) to something else.  You can either edit the&#xd;</xsl:text>
        <xsl:text>    text and replace whatever it mapped to with the caret&#xd;</xsl:text>
        <xsl:text>    (^), which will then display properly as the degree&#xd;</xsl:text>
        <xsl:text>    symbol, or you can select a standard TrueType font.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2009 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
